@@ -28,7 +28,7 @@ from xml.etree.ElementTree import Element, SubElement
 import psutil
 
 from ospd.errors import OspdCommandError
-from ospd.misc import valid_uuid, create_process
+from ospd.misc import valid_uuid
 from ospd.protocol import OspRequest, OspResponse
 from ospd.xml import (
     simple_response_str,
@@ -85,8 +85,9 @@ class BaseCommand(metaclass=InitSubclassMeta):
         }
 
     def __repr__(self):
-        return '<{} description="{}" attributes={} elements={}>'.format(
-            self.name, self.description, self.attributes, self.elements
+        return (
+            f'<{self.name} description="{self.description}" '
+            f'attributes={self.attributes} elements={self.elements}>'
         )
 
 
@@ -113,6 +114,34 @@ class HelpCommand(BaseCommand):
         raise OspdCommandError('Bogus help format', 'help')
 
 
+class CheckFeed(BaseCommand):
+    name = "check_feed"
+    description = 'Perform a sync feed self test and return the status'
+    must_be_initialized = False
+
+    def handle_xml(self, xml: Element) -> bytes:
+        """Handles <check_feed> command.
+
+        Return:
+            Response string for <check_feed> command.
+        """
+
+        feed = Element('feed')
+
+        feed_status = self._daemon.check_feed_self_test()
+
+        if not feed_status or not isinstance(feed_status, dict):
+            raise OspdCommandError('No feed status available', 'check_feed')
+
+        for key, value in feed_status.items():
+            elem = SubElement(feed, key)
+            elem.text = value
+
+        content = [feed]
+
+        return simple_response_str('check_feed', 200, 'OK', content)
+
+
 class GetVersion(BaseCommand):
     name = "get_version"
     description = 'Return various version information'
@@ -156,6 +185,12 @@ class GetVersion(BaseCommand):
             vts = Element('vts')
             elem = SubElement(vts, 'version')
             elem.text = vts_version
+            elem = SubElement(vts, 'vendor')
+            elem.text = self._daemon.get_feed_vendor()
+            elem = SubElement(vts, 'home')
+            elem.text = self._daemon.get_feed_home()
+            elem = SubElement(vts, 'name')
+            elem.text = self._daemon.get_feed_name()
             content.append(vts)
 
         return simple_response_str('get_version', 200, 'OK', content)
@@ -235,7 +270,7 @@ class GetPerformance(BaseCommand):
             output = subprocess.check_output(cmd)
         except (subprocess.CalledProcessError, OSError) as e:
             raise OspdCommandError(
-                'Bogus get_performance format. %s' % e, 'get_performance'
+                f'Bogus get_performance format. {e}', 'get_performance'
             ) from None
 
         return simple_response_str(
@@ -337,7 +372,7 @@ class GetVts(BaseCommand):
 
         if self._daemon.vts and vt_id and vt_id not in self._daemon.vts:
             self._daemon.vts.is_cache_available = True
-            text = "Failed to find vulnerability test '{0}'".format(vt_id)
+            text = f"Failed to find vulnerability test '{vt_id}'"
             raise OspdCommandError(text, 'get_vts', 404)
 
         filtered_vts = None
@@ -358,9 +393,21 @@ class GetVts(BaseCommand):
         yield xml_helper.create_response('get_vts')
 
         begin_vts_tag = xml_helper.create_element('vts')
+
+        # Add Feed information as attributes
         begin_vts_tag = xml_helper.add_attr(
             begin_vts_tag, "vts_version", self._daemon.get_vts_version()
         )
+        begin_vts_tag = xml_helper.add_attr(
+            begin_vts_tag, "feed_vendor", self._daemon.get_feed_vendor()
+        )
+        begin_vts_tag = xml_helper.add_attr(
+            begin_vts_tag, "feed_home", self._daemon.get_feed_home()
+        )
+        begin_vts_tag = xml_helper.add_attr(
+            begin_vts_tag, "feed_name", self._daemon.get_feed_name()
+        )
+
         val = len(self._daemon.vts)
         begin_vts_tag = xml_helper.add_attr(begin_vts_tag, "total", val)
         if filtered_vts and not version_only:
@@ -456,7 +503,7 @@ class GetScans(BaseCommand):
             )
             responses.append(scan)
         else:
-            text = "Failed to find scan '{0}'".format(scan_id)
+            text = f"Failed to find scan '{scan_id}'"
             return simple_response_str('get_scans', 404, text)
 
         return simple_response_str('get_scans', 200, 'OK', responses)
@@ -508,8 +555,8 @@ class StartScan(BaseCommand):
                 self._daemon.max_queued_scans,
             )
             raise OspdCommandError(
-                'Maximum number of queued scans set to %d reached.'
-                % self._daemon.max_queued_scans,
+                'Maximum number of queued scans set to '
+                f'{str(self._daemon.max_queued_scans)} reached.',
                 'start_scan',
             )
 
@@ -551,7 +598,7 @@ class StartScan(BaseCommand):
 
         scanner_params = xml.find('scanner_params')
         if scanner_params is None:
-            raise OspdCommandError('No scanner_params element', 'start_scan')
+            scanner_params = {}
 
         # params are the parameters we got from the <scanner_params> XML.
         params = self._daemon.preprocess_scan_params(scanner_params)
@@ -565,13 +612,7 @@ class StartScan(BaseCommand):
             else:
                 vt_selection = OspRequest.process_vts_params(scanner_vts)
 
-        # Dry run case.
-        dry_run = 'dry_run' in params and int(params['dry_run'])
-        if dry_run:
-            scan_params = None
-        else:
-            scan_params = self._daemon.process_scan_params(params)
-
+        scan_params = self._daemon.process_scan_params(params)
         scan_id_aux = scan_id
         scan_id = self._daemon.create_scan(
             scan_id, scan_target, scan_params, vt_selection
@@ -588,14 +629,6 @@ class StartScan(BaseCommand):
             current_queued_scans + 1,
         )
 
-        if dry_run:
-            scan_func = self._daemon.dry_run_scan
-            scan_process = create_process(
-                func=scan_func, args=(scan_id, scan_target)
-            )
-            self._daemon.scan_processes[scan_id] = scan_process
-            scan_process.start()
-
         id_ = Element('id')
         id_.text = scan_id
 
