@@ -21,14 +21,25 @@
 """
 
 import logging
+import multiprocessing
+import os
+from pathlib import Path
+import re
 import socket
 import ssl
-import multiprocessing
 import time
-import os
 
 from pprint import pformat
-from typing import List, Any, Iterator, Dict, Optional, Iterable, Tuple, Union
+from typing import (
+    List,
+    Any,
+    Iterator,
+    Dict,
+    Optional,
+    Iterable,
+    Tuple,
+    Union,
+)
 from xml.etree.ElementTree import Element, SubElement
 
 import defusedxml.ElementTree as secET
@@ -39,13 +50,18 @@ from ospd import __version__
 from ospd.command import get_commands
 from ospd.errors import OspdCommandError
 from ospd.misc import ResultType, create_process
-from ospd.network import resolve_hostname, target_str_to_list
+from ospd.network import target_str_to_list
 from ospd.protocol import RequestParser
 from ospd.scan import ScanCollection, ScanStatus, ScanProgress
 from ospd.server import BaseServer, Stream
 from ospd.vtfilter import VtsFilter
 from ospd.vts import Vts
-from ospd.xml import elements_as_text, get_result_xml, get_progress_xml
+from ospd.xml import (
+    elements_as_text,
+    get_result_xml,
+    get_progress_xml,
+)
+from ospd.xmlvt import XmlStringVTHelper
 
 logger = logging.getLogger(__name__)
 
@@ -77,6 +93,11 @@ def _terminate_process_group(process: multiprocessing.Process) -> None:
     os.killpg(os.getpgid(process.pid), 15)
 
 
+is_uuid_re = re.compile(
+    '^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$'
+)
+
+
 class OSPDaemon:
 
     """Daemon class for OSP traffic handling.
@@ -108,8 +129,19 @@ class OSPDaemon:
         **kwargs,
     ):  # pylint: disable=unused-argument
         """Initializes the daemon's internal data."""
+
+        def remove_previous_data_pickler_files():
+            logger.debug("removing uuid files in %s", file_storage_dir)
+            root = Path(file_storage_dir)
+            for dp in root.glob('*'):
+                if is_uuid_re.match(dp.name):
+                    if dp.exists():
+                        dp.unlink()
+            return
+
         self.scan_collection = ScanCollection(file_storage_dir)
         self.scan_processes = dict()
+        remove_previous_data_pickler_files()
 
         self.daemon_info = dict()
         self.daemon_info['name'] = "OSPd"
@@ -147,6 +179,9 @@ class OSPDaemon:
 
         self.vts = Vts(storage)
         self.vts_version = None
+        self.feed_name = None
+        self.feed_vendor = None
+        self.feed_home = None
 
         if customvtfilter:
             self.vts_filter = customvtfilter
@@ -245,10 +280,55 @@ class OSPDaemon:
             )
         self.vts_version = vts_version
 
+    def set_feed_vendor(self, feed_vendor: str) -> None:
+        """Set the feed vendor.
+        Parameters:
+            feed_home (str): Identifies the feed home.
+        """
+        if not feed_vendor:
+            raise OspdCommandError(
+                'A feed vendor parameter is required', 'set_feed_vendor'
+            )
+        self.feed_vendor = feed_vendor
+
+    def set_feed_home(self, feed_home: str) -> None:
+        """Set the feed home.
+        Parameters:
+            feed_home (str): Identifies the feed home.
+        """
+        if not feed_home:
+            raise OspdCommandError(
+                'A feed home parameter is required', 'set_feed_home'
+            )
+        self.feed_home = feed_home
+
+    def set_feed_name(self, feed_name: str) -> None:
+        """Set the feed name.
+        Parameters:
+            feed_name (str): Identifies the feed name.
+        """
+        if not feed_name:
+            raise OspdCommandError(
+                'A feed name parameter is required', 'set_feed_name'
+            )
+        self.feed_name = feed_name
+
     def get_vts_version(self) -> Optional[str]:
         """Return the vts version."""
         return self.vts_version
 
+    def get_feed_vendor(self) -> Optional[str]:
+        """Return the feed vendor."""
+        return self.feed_vendor
+
+    def get_feed_home(self) -> Optional[str]:
+        """Return the feed home."""
+        return self.feed_home
+
+    def get_feed_name(self) -> Optional[str]:
+        """Return the feed name."""
+        return self.feed_name
+
     def command_exists(self, name: str) -> bool:
         """Checks if a commands exists."""
         return name in self.commands
@@ -282,7 +362,7 @@ class OSPDaemon:
             params[param.tag] = param.text or ''
 
         # Validate values.
-        for key in params:
+        for key in list(params.keys()):
             param_type = self.get_scanner_param_type(key)
             if not param_type:
                 continue
@@ -292,23 +372,19 @@ class OSPDaemon:
                     params[key] = int(params[key])
                 except ValueError:
                     raise OspdCommandError(
-                        'Invalid %s value' % key, 'start_scan'
+                        f'Invalid {key} value', 'start_scan'
                     ) from None
 
             if param_type == 'boolean':
                 if params[key] not in [0, 1]:
-                    raise OspdCommandError(
-                        'Invalid %s value' % key, 'start_scan'
-                    )
+                    raise OspdCommandError(f'Invalid {key} value', 'start_scan')
             elif param_type == 'selection':
                 selection = self.get_scanner_param_default(key).split('|')
                 if params[key] not in selection:
-                    raise OspdCommandError(
-                        'Invalid %s value' % key, 'start_scan'
-                    )
+                    raise OspdCommandError(f'Invalid {key} value', 'start_scan')
             if self.get_scanner_param_mandatory(key) and params[key] == '':
                 raise OspdCommandError(
-                    'Mandatory %s value is missing' % key, 'start_scan'
+                    f'Mandatory {key} value is missing', 'start_scan'
                 )
 
         return params
@@ -330,9 +406,7 @@ class OSPDaemon:
 
         scan_process = self.scan_processes.get(scan_id)
         if not scan_process:
-            raise OspdCommandError(
-                'Scan not found {0}.'.format(scan_id), 'stop_scan'
-            )
+            raise OspdCommandError(f'Scan not found {scan_id}.', 'stop_scan')
         if not scan_process.is_alive():
             raise OspdCommandError(
                 'Scan already stopped or finished.', 'stop_scan'
@@ -525,7 +599,7 @@ class OSPDaemon:
                     scan_id,
                     name='',
                     host=self.get_scan_host(scan_id),
-                    value='Host process failure (%s).' % e,
+                    value=f'Host process failure ({e}).',
                 )
                 logger.exception('%s: Exception %s while scanning', scan_id, e)
             else:
@@ -548,41 +622,25 @@ class OSPDaemon:
 
             # For debug purposes
             self._get_scan_progress_raw(scan_id)
-        except BrokenPipeError as e:
+        except BrokenPipeError:
             logger.warning(
-                "Error sending data to the client while"
-                " executing a scan %s.",
+                "Error sending data to the client while executing a scan %s.",
                 scan_id,
             )
 
-    def dry_run_scan(self, scan_id: str, target: Dict) -> None:
-        """Dry runs a scan."""
-
-        os.setsid()
-
-        host = resolve_hostname(target.get('hosts'))
-        if host is None:
-            logger.info("Couldn't resolve %s.", self.get_scan_host(scan_id))
-
-        port = self.get_scan_ports(scan_id)
-
-        logger.info("%s:%s: Dry run mode.", host, port)
-
-        self.add_scan_log(scan_id, name='', host=host, value='Dry run result')
-
-        self.finish_scan(scan_id)
-
     def handle_timeout(self, scan_id: str, host: str) -> None:
         """Handles scanner reaching timeout error."""
         self.add_scan_error(
             scan_id,
             host=host,
             name="Timeout",
-            value="{0} exec timeout.".format(self.get_scanner_name()),
+            value=f"{self.get_scanner_name()} exec timeout.",
         )
 
     def sort_host_finished(
-        self, scan_id: str, finished_hosts: Union[List[str], str]
+        self,
+        scan_id: str,
+        finished_hosts: Union[List[str], str],
     ) -> None:
         """Check if the finished host in the list was alive or dead
         and update the corresponding alive_count or dead_count."""
@@ -635,7 +693,10 @@ class OSPDaemon:
         self.set_scan_progress(scan_id)
 
     def set_scan_host_progress(
-        self, scan_id: str, host: str = None, progress: int = None
+        self,
+        scan_id: str,
+        host: str = None,
+        progress: int = None,
     ) -> None:
         """Sets host's progress which is part of target.
         Each time a host progress is updated, the scan progress
@@ -653,7 +714,11 @@ class OSPDaemon:
         host_progress = {host: progress}
         self.set_scan_progress_batch(scan_id, host_progress)
 
-    def get_scan_host_progress(self, scan_id: str, host: str = None) -> int:
+    def get_scan_host_progress(
+        self,
+        scan_id: str,
+        host: str = None,
+    ) -> int:
         """Get host's progress which is part of target."""
         current_progress = self.scan_collection.get_current_target_progress(
             scan_id
@@ -690,18 +755,22 @@ class OSPDaemon:
             attributes = info.get_attributes()
             elements = info.get_elements()
 
-            command_txt = "\t{0: <22} {1}\n".format(name, description)
+            command_txt = f"\t{name: <22} {description}\n"
 
             if attributes:
                 command_txt = ''.join([command_txt, "\t Attributes:\n"])
 
                 for attrname, attrdesc in attributes.items():
-                    attr_txt = "\t  {0: <22} {1}\n".format(attrname, attrdesc)
+                    attr_txt = f"\t  {attrname: <22} {attrdesc}\n"
                     command_txt = ''.join([command_txt, attr_txt])
 
             if elements:
                 command_txt = ''.join(
-                    [command_txt, "\t Elements:\n", elements_as_text(elements)]
+                    [
+                        command_txt,
+                        "\t Elements:\n",
+                        elements_as_text(elements),
+                    ]
                 )
 
             txt += command_txt
@@ -769,7 +838,9 @@ class OSPDaemon:
         )
 
         logging.debug(
-            "%s: Current progress: \n%s", scan_id, pformat(current_progress)
+            "%s: Current progress: \n%s",
+            scan_id,
+            pformat(current_progress),
         )
         return current_progress
 
@@ -834,227 +905,6 @@ class OSPDaemon:
 
         return response
 
-    @staticmethod
-    def get_custom_vt_as_xml_str(  # pylint: disable=unused-argument
-        vt_id: str, custom: Dict
-    ) -> str:
-        """Create a string representation of the XML object from the
-        custom data object.
-        This needs to be implemented by each ospd wrapper, in case
-        custom elements for VTs are used.
-
-        The custom XML object which is returned will be embedded
-        into a <custom></custom> element.
-
-        Returns:
-            XML object as string for custom data.
-        """
-        return ''
-
-    @staticmethod
-    def get_params_vt_as_xml_str(  # pylint: disable=unused-argument
-        vt_id: str, vt_params
-    ) -> str:
-        """Create a string representation of the XML object from the
-        vt_params data object.
-        This needs to be implemented by each ospd wrapper, in case
-        vt_params elements for VTs are used.
-
-        The params XML object which is returned will be embedded
-        into a <params></params> element.
-
-        Returns:
-            XML object as string for vt parameters data.
-        """
-        return ''
-
-    @staticmethod
-    def get_refs_vt_as_xml_str(  # pylint: disable=unused-argument
-        vt_id: str, vt_refs
-    ) -> str:
-        """Create a string representation of the XML object from the
-        refs data object.
-        This needs to be implemented by each ospd wrapper, in case
-        refs elements for VTs are used.
-
-        The refs XML object which is returned will be embedded
-        into a <refs></refs> element.
-
-        Returns:
-            XML object as string for vt references data.
-        """
-        return ''
-
-    @staticmethod
-    def get_dependencies_vt_as_xml_str(  # pylint: disable=unused-argument
-        vt_id: str, vt_dependencies
-    ) -> str:
-        """Create a string representation of the XML object from the
-        vt_dependencies data object.
-        This needs to be implemented by each ospd wrapper, in case
-        vt_dependencies elements for VTs are used.
-
-        The vt_dependencies XML object which is returned will be embedded
-        into a <dependencies></dependencies> element.
-
-        Returns:
-            XML object as string for vt dependencies data.
-        """
-        return ''
-
-    @staticmethod
-    def get_creation_time_vt_as_xml_str(  # pylint: disable=unused-argument
-        vt_id: str, vt_creation_time
-    ) -> str:
-        """Create a string representation of the XML object from the
-        vt_creation_time data object.
-        This needs to be implemented by each ospd wrapper, in case
-        vt_creation_time elements for VTs are used.
-
-        The vt_creation_time XML object which is returned will be embedded
-        into a <vt_creation_time></vt_creation_time> element.
-
-        Returns:
-            XML object as string for vt creation time data.
-        """
-        return ''
-
-    @staticmethod
-    def get_modification_time_vt_as_xml_str(  # pylint: disable=unused-argument
-        vt_id: str, vt_modification_time
-    ) -> str:
-        """Create a string representation of the XML object from the
-        vt_modification_time data object.
-        This needs to be implemented by each ospd wrapper, in case
-        vt_modification_time elements for VTs are used.
-
-        The vt_modification_time XML object which is returned will be embedded
-        into a <vt_modification_time></vt_modification_time> element.
-
-        Returns:
-            XML object as string for vt references data.
-        """
-        return ''
-
-    @staticmethod
-    def get_summary_vt_as_xml_str(  # pylint: disable=unused-argument
-        vt_id: str, summary
-    ) -> str:
-        """Create a string representation of the XML object from the
-        summary data object.
-        This needs to be implemented by each ospd wrapper, in case
-        summary elements for VTs are used.
-
-        The summary XML object which is returned will be embedded
-        into a <summary></summary> element.
-
-        Returns:
-            XML object as string for summary data.
-        """
-        return ''
-
-    @staticmethod
-    def get_impact_vt_as_xml_str(  # pylint: disable=unused-argument
-        vt_id: str, impact
-    ) -> str:
-        """Create a string representation of the XML object from the
-        impact data object.
-        This needs to be implemented by each ospd wrapper, in case
-        impact elements for VTs are used.
-
-        The impact XML object which is returned will be embedded
-        into a <impact></impact> element.
-
-        Returns:
-            XML object as string for impact data.
-        """
-        return ''
-
-    @staticmethod
-    def get_affected_vt_as_xml_str(  # pylint: disable=unused-argument
-        vt_id: str, affected
-    ) -> str:
-        """Create a string representation of the XML object from the
-        affected data object.
-        This needs to be implemented by each ospd wrapper, in case
-        affected elements for VTs are used.
-
-        The affected XML object which is returned will be embedded
-        into a <affected></affected> element.
-
-        Returns:
-            XML object as string for affected data.
-        """
-        return ''
-
-    @staticmethod
-    def get_insight_vt_as_xml_str(  # pylint: disable=unused-argument
-        vt_id: str, insight
-    ) -> str:
-        """Create a string representation of the XML object from the
-        insight data object.
-        This needs to be implemented by each ospd wrapper, in case
-        insight elements for VTs are used.
-
-        The insight XML object which is returned will be embedded
-        into a <insight></insight> element.
-
-        Returns:
-            XML object as string for insight data.
-        """
-        return ''
-
-    @staticmethod
-    def get_solution_vt_as_xml_str(  # pylint: disable=unused-argument
-        vt_id: str, solution, solution_type=None, solution_method=None
-    ) -> str:
-        """Create a string representation of the XML object from the
-        solution data object.
-        This needs to be implemented by each ospd wrapper, in case
-        solution elements for VTs are used.
-
-        The solution XML object which is returned will be embedded
-        into a <solution></solution> element.
-
-        Returns:
-            XML object as string for solution data.
-        """
-        return ''
-
-    @staticmethod
-    def get_detection_vt_as_xml_str(  # pylint: disable=unused-argument
-        vt_id: str, detection=None, qod_type=None, qod=None
-    ) -> str:
-        """Create a string representation of the XML object from the
-        detection data object.
-        This needs to be implemented by each ospd wrapper, in case
-        detection elements for VTs are used.
-
-        The detection XML object which is returned is an element with
-        tag <detection></detection> element
-
-        Returns:
-            XML object as string for detection data.
-        """
-        return ''
-
-    @staticmethod
-    def get_severities_vt_as_xml_str(  # pylint: disable=unused-argument
-        vt_id: str, severities
-    ) -> str:
-        """Create a string representation of the XML object from the
-        severities data object.
-        This needs to be implemented by each ospd wrapper, in case
-        severities elements for VTs are used.
-
-        The severities XML objects which are returned will be embedded
-        into a <severities></severities> element.
-
-        Returns:
-            XML object as string for severities data.
-        """
-        return ''
-
     def get_vt_iterator(  # pylint: disable=unused-argument
         self, vt_selection: List[str] = None, details: bool = True
     ) -> Iterator[Tuple[str, Dict]]:
@@ -1081,60 +931,64 @@ class OSPDaemon:
             elem = SubElement(vt_xml, name)
             elem.text = str(value)
 
+        xml_helper = XmlStringVTHelper()
+
         if vt.get('vt_params'):
-            params_xml_str = self.get_params_vt_as_xml_str(
+            params_xml_str = xml_helper.get_params_vt_as_xml_str(
                 vt_id, vt.get('vt_params')
             )
             vt_xml.append(secET.fromstring(params_xml_str))
 
         if vt.get('vt_refs'):
-            refs_xml_str = self.get_refs_vt_as_xml_str(vt_id, vt.get('vt_refs'))
+            refs_xml_str = xml_helper.get_refs_vt_as_xml_str(
+                vt_id, vt.get('vt_refs')
+            )
             vt_xml.append(secET.fromstring(refs_xml_str))
 
         if vt.get('vt_dependencies'):
-            dependencies = self.get_dependencies_vt_as_xml_str(
+            dependencies = xml_helper.get_dependencies_vt_as_xml_str(
                 vt_id, vt.get('vt_dependencies')
             )
             vt_xml.append(secET.fromstring(dependencies))
 
         if vt.get('creation_time'):
-            vt_ctime = self.get_creation_time_vt_as_xml_str(
+            vt_ctime = xml_helper.get_creation_time_vt_as_xml_str(
                 vt_id, vt.get('creation_time')
             )
             vt_xml.append(secET.fromstring(vt_ctime))
 
         if vt.get('modification_time'):
-            vt_mtime = self.get_modification_time_vt_as_xml_str(
+            vt_mtime = xml_helper.get_modification_time_vt_as_xml_str(
                 vt_id, vt.get('modification_time')
             )
             vt_xml.append(secET.fromstring(vt_mtime))
 
         if vt.get('summary'):
-            summary_xml_str = self.get_summary_vt_as_xml_str(
+            summary_xml_str = xml_helper.get_summary_vt_as_xml_str(
                 vt_id, vt.get('summary')
             )
             vt_xml.append(secET.fromstring(summary_xml_str))
 
         if vt.get('impact'):
-            impact_xml_str = self.get_impact_vt_as_xml_str(
+            impact_xml_str = xml_helper.get_impact_vt_as_xml_str(
                 vt_id, vt.get('impact')
             )
             vt_xml.append(secET.fromstring(impact_xml_str))
 
         if vt.get('affected'):
-            affected_xml_str = self.get_affected_vt_as_xml_str(
+            affected_xml_str = xml_helper.get_affected_vt_as_xml_str(
                 vt_id, vt.get('affected')
             )
             vt_xml.append(secET.fromstring(affected_xml_str))
 
         if vt.get('insight'):
-            insight_xml_str = self.get_insight_vt_as_xml_str(
+            insight_xml_str = xml_helper.get_insight_vt_as_xml_str(
                 vt_id, vt.get('insight')
             )
             vt_xml.append(secET.fromstring(insight_xml_str))
 
         if vt.get('solution'):
-            solution_xml_str = self.get_solution_vt_as_xml_str(
+            solution_xml_str = xml_helper.get_solution_vt_as_xml_str(
                 vt_id,
                 vt.get('solution'),
                 vt.get('solution_type'),
@@ -1143,19 +997,19 @@ class OSPDaemon:
             vt_xml.append(secET.fromstring(solution_xml_str))
 
         if vt.get('detection') or vt.get('qod_type') or vt.get('qod'):
-            detection_xml_str = self.get_detection_vt_as_xml_str(
+            detection_xml_str = xml_helper.get_detection_vt_as_xml_str(
                 vt_id, vt.get('detection'), vt.get('qod_type'), vt.get('qod')
             )
             vt_xml.append(secET.fromstring(detection_xml_str))
 
         if vt.get('severities'):
-            severities_xml_str = self.get_severities_vt_as_xml_str(
+            severities_xml_str = xml_helper.get_severities_vt_as_xml_str(
                 vt_id, vt.get('severities')
             )
             vt_xml.append(secET.fromstring(severities_xml_str))
 
         if vt.get('custom'):
-            custom_xml_str = self.get_custom_vt_as_xml_str(
+            custom_xml_str = xml_helper.get_custom_vt_as_xml_str(
                 vt_id, vt.get('custom')
             )
             vt_xml.append(secET.fromstring(custom_xml_str))
@@ -1214,7 +1068,7 @@ class OSPDaemon:
 
         if not self.initialized and command.must_be_initialized:
             exception = OspdCommandError(
-                '%s is still starting' % self.daemon_info['name'], 'error'
+                f'{self.daemon_info["name"]} is still starting', 'error'
             )
             response = exception.as_xml()
             stream.write(response)
@@ -1294,7 +1148,6 @@ class OSPDaemon:
                     logger.error("Start scan error %s", e)
                     self.stop_scan(scan_id)
                     continue
-
                 scan_func = self.start_scan
                 scan_process = create_process(func=scan_func, args=(scan_id,))
                 self.scan_processes[scan_id] = scan_process
@@ -1370,8 +1223,8 @@ class OSPDaemon:
 
     def wait_for_children(self):
         """Join the zombie process to releases resources."""
-        for scan_id, _ in self.scan_processes.items():
-            self.scan_processes[scan_id].join(0)
+        for _, process in self.scan_processes.items():
+            process.join(0)
 
     def create_scan(
         self,
