@@ -22,7 +22,8 @@ import logging
 import sys
 import time
 
-from typing import List, NewType, Optional, Iterable, Iterator, Tuple
+from typing import List, NewType, Optional, Iterable, Iterator, Tuple, Callable
+from urllib import parse
 
 import redis
 
@@ -49,7 +50,6 @@ NVT_META_FIELDS = [
     "NVT_BIDS_POS",
     "NVT_XREFS_POS",
     "NVT_CATEGORY_POS",
-    "NVT_TIMEOUT_POS",
     "NVT_FAMILY_POS",
     "NVT_NAME_POS",
 ]
@@ -75,12 +75,24 @@ class OpenvasDB:
             settings = Openvas.get_settings()
 
             cls._db_address = settings.get('db_address')
+            if cls._db_address:
+                # translate openvas tcp:// configuration to redis://
+                cls._db_address = cls._db_address.replace("tcp://", "redis://")
+                # translate non scheme to unix://
+                if not parse.urlparse(cls._db_address).scheme:
+                    cls._db_address = "unix://" + cls._db_address
+                if cls._db_address.startswith("redis://"):
+                    logger.warning(
+                        "A Redis TCP connection is being used. "
+                        "This feature is experimental and insecure. "
+                        "It is not recommended in production environments."
+                    )
 
         return cls._db_address
 
     @classmethod
     def create_context(
-        cls, dbnum: Optional[int] = 0, encoding: Optional[str] = 'latin-1'
+        cls, dbnum: int = 0, encoding: str = 'latin-1'
     ) -> RedisCtx:
         """Connect to redis to the given database or to the default db 0 .
 
@@ -93,13 +105,14 @@ class OpenvasDB:
         tries = 5
         while tries:
             try:
-                ctx = redis.Redis(
-                    unix_socket_path=cls.get_database_address(),
+                ctx = redis.Redis.from_url(
+                    url=cls.get_database_address(),
                     db=dbnum,
                     socket_timeout=SOCKET_TIMEOUT,
                     encoding=encoding,
                     decode_responses=True,
                 )
+
                 ctx.keys("test")
             except (redis.exceptions.ConnectionError, FileNotFoundError) as err:
                 logger.debug(
@@ -284,7 +297,9 @@ class OpenvasDB:
         pipe.execute()
 
     @staticmethod
-    def add_single_item(ctx: RedisCtx, name: str, values: Iterable):
+    def add_single_item(
+        ctx: RedisCtx, name: str, values: Iterable, lpush: bool = False
+    ):
         """Add a single KB element with one or more values. Don't add
         duplicated values during this operation, but if the the same
         values already exists under the key, this will not be overwritten.
@@ -301,6 +316,10 @@ class OpenvasDB:
         if not values:
             raise RequiredArgument('add_single_item', 'value')
 
+        if lpush:
+            ctx.lpush(name, *set(values))
+            return
+
         ctx.rpush(name, *set(values))
 
     @staticmethod
@@ -372,24 +391,44 @@ class OpenvasDB:
 
     @classmethod
     def get_filenames_and_oids(
-        cls,
-        ctx: RedisCtx,
+        cls, ctx: RedisCtx, pattern: str, parser: Callable[[str], str]
     ) -> Iterable[Tuple[str, str]]:
         """Get all items with index 'index', stored under
         a given pattern.
 
         Arguments:
             ctx: Redis context to use.
+            pattern: Pattern used for searching the keys
+            parser: Callable method to remove the pattern from the keys.
 
         Return an iterable where each single tuple contains the filename
             as first element and the oid as the second one.
         """
         if not ctx:
             raise RequiredArgument('get_filenames_and_oids', 'ctx')
+        if not pattern:
+            raise RequiredArgument('get_filenames_and_oids', 'pattern')
+        if not parser:
+            raise RequiredArgument('get_filenames_and_oids', 'parser')
 
-        items = cls.get_keys_by_pattern(ctx, 'nvt:*')
+        items = cls.get_keys_by_pattern(ctx, pattern)
 
-        return ((ctx.lindex(item, 0), item[4:]) for item in items)
+        return ((ctx.lindex(item, 0), parser(item)) for item in items)
+
+    @staticmethod
+    def exists(ctx: RedisCtx, key: str) -> bool:
+        """Check that the given key exists in the given context.
+
+        Arguments:
+            ctx: Redis context to use.
+            patternkey: key to check.
+
+        Return a True if exists, False otherwise.
+        """
+        if not ctx:
+            raise RequiredArgument('exists', 'ctx')
+
+        return ctx.exists(key) == 1
 
 
 class BaseDB:
@@ -402,7 +441,7 @@ class BaseDB:
         self.index = kbindex
 
     def flush(self):
-        """ Flush the database """
+        """Flush the database"""
         self.ctx.flushdb()
 
 
@@ -478,7 +517,7 @@ class BaseKbDB(BaseDB):
 
 
 class ScanDB(BaseKbDB):
-    """ Database for a scanning a single host """
+    """Database for a scanning a single host"""
 
     def select(self, kbindex: int) -> "ScanDB":
         """Select a redis kb.
@@ -538,7 +577,7 @@ class KbDB(BaseKbDB):
         self._remove_list_item('internal/dbindex', scan_db.index)
 
     def target_is_finished(self, scan_id: str) -> bool:
-        """ Check if a target has finished. """
+        """Check if a target has finished."""
 
         status = self._get_single_item(f'internal/{scan_id}')
 
@@ -568,7 +607,7 @@ class KbDB(BaseKbDB):
 
 
 class MainDB(BaseDB):
-    """ Main Database """
+    """Main Database"""
 
     DEFAULT_INDEX = 0
 
@@ -635,6 +674,25 @@ class MainDB(BaseDB):
 
         return None
 
+    def check_consistency(self, scan_id) -> Tuple[Optional[KbDB], int]:
+        """Check if the current scan id already exists in a kb.
+
+        Return a tuple with the kb or none, and an error code, being 0 if
+        the db is clean, -1 on old finished scan, -2 on still running scan.
+        """
+        err = 0
+
+        kb = self.find_kb_database_by_scan_id(scan_id)
+        current_status = None
+        if kb:
+            current_status = kb.get_status(scan_id)
+        if current_status == "finished":
+            err = -1
+        elif current_status == "stop_all" or current_status == "ready":
+            err = -2
+
+        return (kb, err)
+
     def release_database(self, database: BaseDB):
         self.release_database_by_index(database.index)
         database.flush()
