@@ -50,6 +50,7 @@ class NVTICache(BaseDB):
         'executable_version': '80',
         'remote_analysis': '70',
         'remote_probe': '50',
+        'package_unreliable': '30',
         'remote_banner_unreliable': '30',
         'executable_version_unreliable': '30',
         'general_note': '1',
@@ -80,16 +81,24 @@ class NVTICache(BaseDB):
             # no nvti cache db available yet
             return None
 
+        # no feed version for notus otherwise tha would be a contract change
         return OpenvasDB.get_single_item(self.ctx, NVTI_CACHE_NAME)
 
     def get_oids(self) -> Iterator[Tuple[str, str]]:
         """Get the list of NVT file names and OIDs.
 
         Returns:
-            A i. Each single list contains the filename
-            as first element and the oid as second one.
+            An iterable of tuples of file name and oid.
         """
-        return OpenvasDB.get_filenames_and_oids(self.ctx)
+
+        def parse_oid(item):
+            return item[4:]
+
+        if self.ctx:
+            for f, oid in OpenvasDB.get_filenames_and_oids(
+                self.ctx, 'nvt:*', parse_oid
+            ):
+                yield (f, oid)
 
     def get_nvt_params(self, oid: str) -> Optional[Dict[str, str]]:
         """Get NVT's preferences.
@@ -181,35 +190,22 @@ class NVTICache(BaseDB):
             'bid',
             'xref',
             'category',
-            'timeout',
             'family',
             'name',
         ]
 
         custom = dict()
         custom['refs'] = dict()
-        custom['vt_params'] = dict()
         for child, res in zip(subelem, resp):
-            if child not in ['cve', 'bid', 'xref', 'tag', 'timeout'] and res:
+            if child not in ['cve', 'bid', 'xref', 'tag'] and res:
                 custom[child] = res
             elif child == 'tag':
                 custom.update(self._parse_metadata_tags(res, oid))
             elif child in ['cve', 'bid', 'xref'] and res:
                 custom['refs'][child] = res.split(", ")
-            elif child == 'timeout':
-                if res is None:
-                    continue
-                vt_params = {}
-                if int(res) > 0:
-                    _param_id = '0'
-                    vt_params[_param_id] = dict()
-                    vt_params[_param_id]['id'] = _param_id
-                    vt_params[_param_id]['type'] = 'entry'
-                    vt_params[_param_id]['name'] = 'timeout'
-                    vt_params[_param_id]['description'] = 'Script Timeout'
-                    vt_params[_param_id]['default'] = res
-                custom['vt_params'] = vt_params
-                custom['vt_params'].update(self.get_nvt_params(oid))
+
+        custom['vt_params'] = dict()
+        custom['vt_params'].update(self.get_nvt_params(oid))
 
         return custom
 
@@ -240,7 +236,7 @@ class NVTICache(BaseDB):
 
         return refs
 
-    def get_nvt_family(self, oid: str) -> str:
+    def get_nvt_family(self, oid: str) -> Optional[str]:
         """Get NVT family
         Arguments:
             oid: OID of VT from which to get the VT family.
@@ -265,24 +261,9 @@ class NVTICache(BaseDB):
             A list with the VT preferences.
         """
         key = f'oid:{oid}:prefs'
+        # notus doesn't seem to have preferences, ignoring
         return OpenvasDB.get_list_item(self.ctx, key)
 
-    def get_nvt_timeout(self, oid: str) -> Optional[str]:
-        """Get NVT timeout
-
-        Arguments:
-            ctx: Redis context to be used.
-            oid: OID of VT from which to get the script timeout.
-
-        Returns:
-            The timeout.
-        """
-        return OpenvasDB.get_single_item(
-            self.ctx,
-            f"nvt:{oid}",
-            index=NVT_META_FIELDS.index("NVT_TIMEOUT_POS"),
-        )
-
     def get_nvt_tags(self, oid: str) -> Optional[Dict[str, str]]:
         """Get Tags of the given OID.
 
@@ -308,9 +289,6 @@ class NVTICache(BaseDB):
     def get_nvt_count(self) -> int:
         return OpenvasDB.get_key_count(self.ctx, "nvt:*")
 
-    def force_reload(self):
-        self._main_db.release_database(self)
-
     def add_vt_to_cache(self, vt_id: str, vt: List[str]):
         if not vt_id:
             raise RequiredArgument('add_vt_to_cache', 'vt_id')
