@@ -27,11 +27,12 @@ import logging
 import binascii
 
 from enum import IntEnum
-from typing import Optional, Dict, List, Tuple
+from typing import Callable, Optional, Dict, List, Tuple
 from base64 import b64decode
 
 from ospd.scan import ScanCollection, ScanStatus
 from ospd.ospd import BASE_SCANNER_PARAMS
+from ospd.network import valid_port_list
 from ospd_openvas.openvas import Openvas
 from ospd_openvas.db import KbDB
 from ospd_openvas.nvticache import NVTICache
@@ -96,6 +97,7 @@ class PreferenceHandler:
         kbdb: KbDB,
         scan_collection: ScanCollection,
         nvticache: NVTICache,
+        is_handled_by_notus: Callable[[str], bool],
     ):
         self.scan_id = scan_id
         self.kbdb = kbdb
@@ -105,6 +107,11 @@ class PreferenceHandler:
         self._nvts_params = None
 
         self.nvti = nvticache
+        if is_handled_by_notus:
+            self.is_handled_by_notus = is_handled_by_notus
+        else:
+            self.is_handled_by_notus = lambda _: False
+        self.errors = []
 
     def prepare_scan_id_for_openvas(self):
         """Create the openvas scan id and store it in the redis kb.
@@ -112,6 +119,12 @@ class PreferenceHandler:
         """
         self.kbdb.add_scan_id(self.scan_id)
 
+    def get_error_messages(self) -> List:
+        """Returns the Error List and reset it"""
+        ret = self.errors
+        self.errors = []
+        return ret
+
     @property
     def target_options(self) -> Dict:
         """Return target options from Scan collection"""
@@ -139,8 +152,13 @@ class PreferenceHandler:
         vts_list = list()
         families = dict()
 
+        # Only get vts from NVTICache. Does not include Notus advisories,
+        # since they are handled by Notus.
         oids = self.nvti.get_oids()
 
+        # Same here. Only check for families in NVT Cache.
+        # If necessary, consider to call get_advisory_famaly from
+        # Notus class
         for _, oid in oids:
             family = self.nvti.get_nvt_family(oid)
             if family not in families:
@@ -176,16 +194,12 @@ class PreferenceHandler:
         """Check if the value of a vt parameter matches with
         the type founded.
         """
-        if (
-            param_type
-            in [
-                'entry',
-                'password',
-                'radio',
-                'sshlogin',
-            ]
-            and isinstance(vt_param_value, str)
-        ):
+        if param_type in [
+            'entry',
+            'password',
+            'radio',
+            'sshlogin',
+        ] and isinstance(vt_param_value, str):
             return None
         elif param_type == 'checkbox' and (
             vt_param_value == '0' or vt_param_value == '1'
@@ -215,8 +229,11 @@ class PreferenceHandler:
         vts_params = {}
         vtgroups = vts.pop('vt_groups')
 
-        vthelper = VtHelper(self.nvti)
+        vthelper = VtHelper(self.nvti, None)
 
+        # This get vt groups which are not Notus Family.
+        # Since Notus advisories are handled by notus, they
+        # are not sent to Openvas-scanner
         if vtgroups:
             vts_list = self._get_vts_in_groups(vtgroups)
 
@@ -230,6 +247,11 @@ class PreferenceHandler:
                 ):
                     break
 
+            # Remove oids handled by notus
+            if self.is_handled_by_notus(vtid):
+                logger.debug('The VT %s is handled by notus. Ignoring.', vtid)
+                continue
+
             vt = vthelper.get_single_vt(vtid)
             if not vt:
                 logger.warning(
@@ -272,12 +294,9 @@ class PreferenceHandler:
                 if type_aux == 'checkbox':
                     vt_param_value = _from_bool_to_str(int(vt_param_value))
 
-                if vt_param_id == '0':
-                    vts_params[f"timeout.{vtid}"] = str(vt_param_value)
-                else:
-                    vts_params[
-                        f"{vtid}:{vt_param_id}:{param_type}:{param_name}"
-                    ] = str(vt_param_value)
+                vts_params[
+                    f'{vtid}:{vt_param_id}:{param_type}:{param_name}'
+                ] = str(vt_param_value)
 
         return vts_list, vts_params
 
@@ -286,6 +305,7 @@ class PreferenceHandler:
         The plugin list is immediately stored in the kb.
         """
         nvts = self.scan_collection.get_vts(self.scan_id)
+
         if nvts:
             nvts_list, self._nvts_params = self._process_vts(nvts)
             # Add nvts list
@@ -293,10 +313,6 @@ class PreferenceHandler:
             plugin_list = f'plugin_set|||{separ.join(nvts_list)}'
             self.kbdb.add_scan_preferences(self.scan_id, [plugin_list])
 
-            nvts_list = None
-            plugin_list = None
-            nvts = None
-
             return True
 
         return False
@@ -526,6 +542,9 @@ class PreferenceHandler:
         """Get the port list from the scan collection and store the list
         in the kb."""
         ports = self.scan_collection.get_ports(self.scan_id)
+        if not valid_port_list(ports):
+            return False
+
         port_range = f'port_range|||{ports}'
         self.kbdb.add_scan_preferences(self.scan_id, [port_range])
 
@@ -571,8 +590,7 @@ class PreferenceHandler:
         if prefs_val:
             self.kbdb.add_scan_preferences(self.scan_id, prefs_val)
 
-    @staticmethod
-    def build_credentials_as_prefs(credentials: Dict) -> List[str]:
+    def build_credentials_as_prefs(self, credentials: Dict) -> List[str]:
         """Parse the credential dictionary.
         Arguments:
             credentials: Dictionary with the credentials.
@@ -589,28 +607,36 @@ class PreferenceHandler:
             username = cred_params.get('username', '')
             password = cred_params.get('password', '')
 
+            # Check service ssh
             if service == 'ssh':
-                port = cred_params.get('port', '')
+                # For ssh check the Port
+                port = cred_params.get('port', '22')
                 priv_username = cred_params.get('priv_username', '')
                 priv_password = cred_params.get('priv_password', '')
-                cred_prefs_list.append(f'auth_port_ssh|||{port}')
-                cred_prefs_list.append(
-                    f'{OID_SSH_AUTH}:7:'
-                    f'entry:SSH privilege login name:|||{priv_username}'
-                )
-                cred_prefs_list.append(
-                    f'{OID_SSH_AUTH}:8:'
-                    f'password:SSH privilege password:|||{priv_password}'
-                )
-                cred_prefs_list.append(
-                    f'{OID_SSH_AUTH}:1:entry:SSH login name:|||{username}'
-                )
+                if not port:
+                    port = '22'
+                    warning = (
+                        "Missing port number for ssh credentials. "
+                        "Using default port 22."
+                    )
+                    logger.warning(warning)
+                elif not port.isnumeric():
+                    self.errors.append(
+                        f"Port for SSH '{port}' is not a valid number."
+                    )
+                    continue
+                elif int(port) > 65535 or int(port) < 1:
+                    self.errors.append(
+                        f"Port for SSH is out of range (1-65535): {port}"
+                    )
+                    continue
+                # For ssh check the credential type
                 if cred_type == 'up':
                     cred_prefs_list.append(
                         f'{OID_SSH_AUTH}:3:password:SSH password '
                         f'(unsafe!):|||{password}'
                     )
-                else:
+                elif cred_type == 'usk':
                     private = cred_params.get('private', '')
                     cred_prefs_list.append(
                         f'{OID_SSH_AUTH}:2:password:SSH key passphrase:|||'
@@ -620,14 +646,41 @@ class PreferenceHandler:
                         f'{OID_SSH_AUTH}:4:file:SSH private key:|||'
                         f'{private}'
                     )
-            if service == 'smb':
+                elif cred_type:
+                    self.errors.append(
+                        f"Unknown Credential Type for SSH: {cred_type}. "
+                        "Use 'up' for Username + Password or 'usk' for "
+                        "Username + SSH Key."
+                    )
+                    continue
+                else:
+                    self.errors.append(
+                        "Missing Credential Type for SSH. Use 'up' for "
+                        "Username + Password or 'usk' for Username + SSH Key."
+                    )
+                    continue
+                cred_prefs_list.append(f'auth_port_ssh|||{port}')
+                cred_prefs_list.append(
+                    f'{OID_SSH_AUTH}:1:entry:SSH login name:|||{username}'
+                )
+                cred_prefs_list.append(
+                    f'{OID_SSH_AUTH}:7:entry:SSH privilege login name:'
+                    f'|||{priv_username}'
+                )
+                cred_prefs_list.append(
+                    f'{OID_SSH_AUTH}:8:password:SSH privilege password:'
+                    f'|||{priv_password}'
+                )
+            # Check servic smb
+            elif service == 'smb':
                 cred_prefs_list.append(
                     f'{OID_SMB_AUTH}:1:entry:SMB login:|||{username}'
                 )
                 cred_prefs_list.append(
                     f'{OID_SMB_AUTH}:2:password:SMB password:|||{password}'
                 )
-            if service == 'esxi':
+            # Check service esxi
+            elif service == 'esxi':
                 cred_prefs_list.append(
                     f'{OID_ESXI_AUTH}:1:entry:ESXi login name:|||{username}'
                 )
@@ -635,13 +688,47 @@ class PreferenceHandler:
                     f'{OID_ESXI_AUTH}:2:password:ESXi login password:|||'
                     f'{password}'
                 )
-
-            if service == 'snmp':
+            # Check service snmp
+            elif service == 'snmp':
                 community = cred_params.get('community', '')
                 auth_algorithm = cred_params.get('auth_algorithm', '')
                 privacy_password = cred_params.get('privacy_password', '')
                 privacy_algorithm = cred_params.get('privacy_algorithm', '')
 
+                if not privacy_algorithm:
+                    if privacy_password:
+                        self.errors.append(
+                            "When no privacy algorithm is used, the privacy"
+                            + " password also has to be empty."
+                        )
+                        continue
+                elif (
+                    not privacy_algorithm == "aes"
+                    and not privacy_algorithm == "des"
+                ):
+                    self.errors.append(
+                        "Unknown privacy algorithm used: "
+                        + privacy_algorithm
+                        + ". Use 'aes', 'des' or '' (none)."
+                    )
+                    continue
+
+                if not auth_algorithm:
+                    self.errors.append(
+                        "Missing authentication algorithm for SNMP."
+                        + " Use 'md5' or 'sha1'."
+                    )
+                    continue
+                elif (
+                    not auth_algorithm == "md5" and not auth_algorithm == "sha1"
+                ):
+                    self.errors.append(
+                        "Unknown authentication algorithm: "
+                        + auth_algorithm
+                        + ". Use 'md5' or 'sha1'."
+                    )
+                    continue
+
                 cred_prefs_list.append(
                     f'{OID_SNMP_AUTH}:1:password:SNMP Community:|||{community}'
                 )
@@ -663,12 +750,19 @@ class PreferenceHandler:
                     f'{OID_SNMP_AUTH}:6:radio:SNMPv3 Privacy Algorithm:|||'
                     f'{privacy_algorithm}'
                 )
+            elif service:
+                self.errors.append(
+                    f"Unknown service type for credential: {service}"
+                )
+            else:
+                self.errors.append("Missing service type for credential.")
 
         return cred_prefs_list
 
     def prepare_credentials_for_openvas(self) -> bool:
         """Get the credentials from the scan collection and store them
         in the kb."""
+        logger.debug("Looking for given Credentials...")
         credentials = self.scan_collection.get_credentials(self.scan_id)
         if credentials:
             cred_prefs = self.build_credentials_as_prefs(credentials)
@@ -676,7 +770,9 @@ class PreferenceHandler:
                 self.kbdb.add_credentials_to_scan_preferences(
                     self.scan_id, cred_prefs
                 )
-
+                logger.debug("Credentials added to the kb.")
+        else:
+            logger.debug("No credentials found.")
         if credentials and not cred_prefs:
             return False
 
