@@ -20,17 +20,31 @@
 """ Provide functions to handle VT Info. """
 
 from hashlib import sha256
-from typing import Optional, Dict, List, Tuple, Iterator
+import logging
+from typing import Any, Optional, Dict, List, Tuple, Iterator
+from itertools import chain
 
+from ospd.cvss import CVSS
 from ospd_openvas.nvticache import NVTICache
+from ospd_openvas.notus import Notus
+
+logger = logging.getLogger(__name__)
 
 
 class VtHelper:
-    def __init__(self, nvticache: NVTICache):
+    def __init__(self, nvticache: NVTICache, notus: Optional[Notus] = None):
         self.nvti = nvticache
+        self.notus = notus
 
-    def get_single_vt(self, vt_id: str, oids=None) -> Optional[Dict[str, any]]:
-        custom = self.nvti.get_nvt_metadata(vt_id)
+    def get_single_vt(self, vt_id: str, oids=None) -> Optional[Dict[str, Any]]:
+        nr = None
+        if self.notus:
+            nr = self.notus.get_nvt_metadata(vt_id)
+
+        if nr:
+            custom = nr
+        else:
+            custom = self.nvti.get_nvt_metadata(vt_id)
 
         if not custom:
             return None
@@ -47,6 +61,9 @@ class VtHelper:
                 deps = custom.pop('dependencies')
                 deps_list = deps.split(', ')
                 for dep_name in deps_list:
+                    # this will bug out on notus since notus does contain
+                    # multiple oids per advisory; however luckily they don't
+                    # have dependencies; otherwise it must be treated as a list
                     dep_oid = oids.get(dep_name)
                     if dep_oid:
                         vt_dependencies.append(dep_oid)
@@ -89,10 +106,17 @@ class VtHelper:
             qod_v = custom.pop('qod')
 
         severity = dict()
+
         if 'severity_vector' in custom:
             severity_vector = custom.pop('severity_vector')
         else:
-            severity_vector = custom.pop('cvss_base_vector')
+            severity_vector = custom.pop('cvss_base_vector', None)
+        if not severity_vector:
+            logger.warning("no severity_vector in %s found.", vt_id)
+            # when there is no severity than we return None; alternatively we
+            # could set it to an empty dict and continue
+            # severity_vector = {}
+            return None
         severity['severity_base_vector'] = severity_vector
 
         if "CVSS:3" in severity_vector:
@@ -157,26 +181,35 @@ class VtHelper:
     def get_vt_iterator(
         self, vt_selection: List[str] = None, details: bool = True
     ) -> Iterator[Tuple[str, Dict]]:
-        """ Yield the vts from the Redis NVTicache. """
+        """Yield the vts from the Redis NVTicache."""
 
         oids = None
         if not vt_selection or details:
-            vt_collection = dict(self.nvti.get_oids())
+            # notus contains multiple oids per advisory therefore unlike
+            # nasl they share the filename
+            # The vt collection is taken from both Caches
+            if self.notus:
+                vt_collection = chain(
+                    self.notus.get_oids(), self.nvti.get_oids()
+                )
+            else:
+                vt_collection = self.nvti.get_oids()
 
             if not vt_selection:
-                vt_selection = vt_collection.values()
+                vt_selection = [v for _, v in vt_collection]
 
             if details:
-                oids = vt_collection
+                # luckily notus doesn't have dependency therefore we can
+                # treat oids for dependency lookup as a dict
+                oids = dict(vt_collection)
 
+        vt_selection.sort()
         for vt_id in vt_selection:
             vt = self.get_single_vt(vt_id, oids)
-            yield (vt_id, vt)
-
-    def calculate_vts_collection_hash(self) -> str:
-        """ Calculate the vts collection sha256 hash. """
-        m = sha256()  # pylint: disable=invalid-name
+            if vt:
+                yield (vt_id, vt)
 
+    def vt_verification_string_iter(self) -> str:
         # for a reproducible hash calculation
         # the vts must already be sorted in the dictionary.
         for vt_id, vt in self.get_vt_iterator(details=False):
@@ -184,15 +217,40 @@ class VtHelper:
             vt_params = vt.get('vt_params')
             if vt_params:
                 for _, param in sorted(vt_params.items()):
-                    param_chain += (
-                        param.get('id')
-                        + param.get('name')
-                        + param.get('default')
-                    )
-
-            m.update(
+                    if param:
+                        param_chain += (
+                            param.get('id')
+                            + param.get('name')
+                            + param.get('default')
+                        )
+            yield (
                 (vt_id + vt.get('modification_time')).encode('utf-8')
                 + param_chain.encode('utf-8')
             )
 
+    def calculate_vts_collection_hash(self) -> str:
+        """Calculate the vts collection sha256 hash."""
+        m = sha256()  # pylint: disable=invalid-name
+
+        for chunk in self.vt_verification_string_iter():
+            m.update(chunk)
         return m.hexdigest()
+
+    def get_severity_score(self, vt_aux: dict) -> Optional[float]:
+        """Return the severity score for the given oid.
+        Arguments:
+            vt_aux: VT element from which to get the severity vector
+        Returns:
+            The calculated cvss base value. None if there is no severity
+            vector or severity type is not cvss base version 2.
+        """
+        if vt_aux:
+            severity_type = vt_aux['severities'].get('severity_type')
+            severity_vector = vt_aux['severities'].get('severity_base_vector')
+
+            if severity_type == "cvss_base_v2" and severity_vector:
+                return CVSS.cvss_base_v2_value(severity_vector)
+            elif severity_type == "cvss_base_v3" and severity_vector:
+                return CVSS.cvss_base_v3_value(severity_vector)
+
+        return None
