@@ -74,11 +74,13 @@ class TestNVTICache(TestCase):
         )
 
     def test_get_oids(self, MockOpenvasDB):
-        MockOpenvasDB.get_filenames_and_oids.return_value = ['oids']
+        MockOpenvasDB.get_filenames_and_oids.return_value = [
+            ('filename', 'oid')
+        ]
 
         resp = self.nvti.get_oids()
 
-        self.assertEqual(resp, ['oids'])
+        self.assertEqual([x for x in resp], [('filename', 'oid')])
 
     def test_parse_metadata_tag_missing_value(self, MockOpenvasDB):
         logging.Logger.error = Mock()
@@ -174,7 +176,6 @@ class TestNVTICache(TestCase):
             '',
             'URL:http://www.mantisbt.org/',
             '3',
-            '10',
             'Product detection',
             'Mantis Detection',
         ]
@@ -204,7 +205,7 @@ class TestNVTICache(TestCase):
                     'id': '0',
                     'type': 'entry',
                     'name': 'timeout',
-                    'description': 'Script Timeout',
+                    'description': 'Description',
                     'default': '10',
                 },
                 '1': {
@@ -217,7 +218,10 @@ class TestNVTICache(TestCase):
             },
         }
 
-        prefs1 = ['1|||dns-fuzz.timelimit|||entry|||default']
+        prefs1 = [
+            '0|||timeout|||entry|||10',
+            '1|||dns-fuzz.timelimit|||entry|||default',
+        ]
 
         MockOpenvasDB.get_list_item.side_effect = [metadata, prefs1]
         resp = self.nvti.get_nvt_metadata('1.2.3.4')
@@ -261,13 +265,6 @@ class TestNVTICache(TestCase):
 
         self.assertEqual(resp, prefs)
 
-    def test_get_nvt_timeout(self, MockOpenvasDB):
-        MockOpenvasDB.get_single_item.return_value = '300'
-
-        resp = self.nvti.get_nvt_timeout('1.2.3.4')
-
-        self.assertEqual(resp, '300')
-
     def test_get_nvt_tags(self, MockOpenvasDB):
         tag = (
             'last_modification=1533906565'
@@ -305,11 +302,6 @@ class TestNVTICache(TestCase):
         self.assertEqual(self.nvti.get_nvt_count(), 20)
         MockOpenvasDB.get_key_count.assert_called_with('foo', 'nvt:*')
 
-    def test_force_reload(self, _MockOpenvasDB):
-        self.nvti.force_reload()
-
-        self.db.release_database.assert_called_with(self.nvti)
-
     def test_flush(self, _MockOpenvasDB):
         self.nvti._ctx = Mock()
 
