@@ -49,7 +49,7 @@ class PreferenceHandlerTestCase(TestCase):
         }
 
         p_handler = PreferenceHandler(
-            '1234-1234', mock_kb, dummy.scan_collection, dummy.nvti
+            '1234-1234', mock_kb, dummy.scan_collection, dummy.nvti, None
         )
         dummy.nvti.get_nvt_metadata.return_value = None
         p_handler._process_vts(vts)  # pylint: disable = protected-access
@@ -65,13 +65,29 @@ class PreferenceHandlerTestCase(TestCase):
         }
 
         p_handler = PreferenceHandler(
-            '1234-1234', None, dummy.scan_collection, dummy.nvti
+            '1234-1234', None, dummy.scan_collection, dummy.nvti, None
         )
 
         ret = p_handler._process_vts(vts)  # pylint: disable = protected-access
 
         self.assertFalse(ret[1])
 
+    def test_not_append_notus_oids(self):
+        dummy = DummyDaemon()
+
+        vts = {
+            '1.3.6.1.4.1.25623.1.0.100061': {'1': 'new value'},
+            'vt_groups': ['family=debian', 'family=general'],
+        }
+
+        p_handler = PreferenceHandler(
+            '1234-1234', None, dummy.scan_collection, dummy.nvti, lambda _: True
+        )
+        re = p_handler._process_vts(vts)  # pylint: disable = protected-access
+
+        self.assertEqual(re[0], [])
+        self.assertEqual(re[1], {})
+
     def test_process_vts(self):
         dummy = DummyDaemon()
 
@@ -85,7 +101,7 @@ class PreferenceHandlerTestCase(TestCase):
         )
 
         p_handler = PreferenceHandler(
-            '1234-1234', None, dummy.scan_collection, dummy.nvti
+            '1234-1234', None, dummy.scan_collection, dummy.nvti, None
         )
         ret = p_handler._process_vts(vts)  # pylint: disable = protected-access
 
@@ -99,7 +115,7 @@ class PreferenceHandlerTestCase(TestCase):
         dummy.scan_collection.get_vts.return_value = {}
 
         p_handler = PreferenceHandler(
-            '1234-1234', mock_kb, dummy.scan_collection, dummy.nvti
+            '1234-1234', mock_kb, dummy.scan_collection, dummy.nvti, None
         )
         p_handler.kbdb.add_scan_preferences = Mock()
         ret = p_handler.prepare_plugins_for_openvas()
@@ -119,7 +135,7 @@ class PreferenceHandlerTestCase(TestCase):
         dummy.scan_collection.get_vts.return_value = vts
 
         p_handler = PreferenceHandler(
-            '1234-1234', mock_kb, dummy.scan_collection, dummy.nvti
+            '1234-1234', mock_kb, dummy.scan_collection, dummy.nvti, None
         )
         p_handler.kbdb.add_scan_preferences = Mock()
         ret = p_handler.prepare_plugins_for_openvas()
@@ -131,13 +147,12 @@ class PreferenceHandlerTestCase(TestCase):
 
         cred_out = [
             'auth_port_ssh|||22',
-            '1.3.6.1.4.1.25623.1.0.103591:7:'
-            'entry:SSH privilege login name:|||test',
-            '1.3.6.1.4.1.25623.1.0.103591:8:'
-            'password:SSH privilege password:|||1234',
             '1.3.6.1.4.1.25623.1.0.103591:1:entry:SSH login name:|||username',
             '1.3.6.1.4.1.25623.1.0.103591:3:'
             'password:SSH password (unsafe!):|||pass',
+            '1.3.6.1.4.1.25623.1.0.103591:7:entry:SSH privilege login name:|||',
+            '1.3.6.1.4.1.25623.1.0.103591:8:'
+            'password:SSH privilege password:|||',
         ]
         cred_dict = {
             'ssh': {
@@ -145,17 +160,15 @@ class PreferenceHandlerTestCase(TestCase):
                 'port': '22',
                 'username': 'username',
                 'password': 'pass',
-                'priv_username': 'test',
-                'priv_password': '1234',
             }
         }
         p_handler = PreferenceHandler(
-            '1234-1234', None, dummy.scan_collection, None
+            '1234-1234', None, dummy.scan_collection, None, None
         )
 
         ret = p_handler.build_credentials_as_prefs(cred_dict)
 
-        self.assertEqual(ret, cred_out)
+        self.assertCountEqual(ret, cred_out)
 
     def test_build_credentials(self):
         dummy = DummyDaemon()
@@ -169,35 +182,36 @@ class PreferenceHandlerTestCase(TestCase):
             '1.3.6.1.4.1.25623.1.0.103591:2:'
             'password:SSH key passphrase:|||pass',
             '1.3.6.1.4.1.25623.1.0.103591:4:file:SSH private key:|||',
+            '1.3.6.1.4.1.25623.1.0.103591:7:'
+            'entry:SSH privilege login name:|||',
+            '1.3.6.1.4.1.25623.1.0.103591:8:'
+            'password:SSH privilege password:|||',
             '1.3.6.1.4.1.25623.1.0.90023:1:entry:SMB login:|||username',
             '1.3.6.1.4.1.25623.1.0.90023:2:password]:SMB password :|||pass',
             '1.3.6.1.4.1.25623.1.0.105076:1:'
             'password:SNMP Community:some comunity',
             '1.3.6.1.4.1.25623.1.0.105076:2:entry:SNMPv3 Username:username',
             '1.3.6.1.4.1.25623.1.0.105076:3:password:SNMPv3 Password:pass',
-            '1.3.6.1.4.1.25623.1.0.105076:4:'
-            'radio:SNMPv3 Authentication Algorithm:some auth algo',
-            '1.3.6.1.4.1.25623.1.0.105076:5:'
-            'password:SNMPv3 Privacy Password:privacy pass',
-            '1.3.6.1.4.1.25623.1.0.105076:6:'
-            'radio:SNMPv3 Privacy Algorithm:privacy algo',
-            '1.3.6.1.4.1.25623.1.0.105076:7:'
-            'entry:SSH privilege login name:|||test',
-            '1.3.6.1.4.1.25623.1.0.105076:8:'
-            'password:SSH privilege password:|||1234',
+            '1.3.6.1.4.1.25623.1.0.105076:4:radio:SNMPv3'
+            ' Authentication Algorithm:some auth algo',
+            '1.3.6.1.4.1.25623.1.0.105076:5:password:'
+            'SNMPv3 Privacy Password:privacy pass',
+            '1.3.6.1.4.1.25623.1.0.105076:6:radio:'
+            'SNMPv3 Privacy Algorithm:privacy algo',
         ]
         cred_dict = {
             'ssh': {
-                'type': 'ssh',
+                'type': 'usk',
                 'port': '22',
                 'username': 'username',
                 'password': 'pass',
-                'priv_username': 'test',
-                'priv_password': '1234',
+                'private': 'some key',
+                'priv_username': 'su_user',
+                'priv_password': 'su_pass',
             },
-            'smb': {'type': 'smb', 'username': 'username', 'password': 'pass'},
+            'smb': {'type': 'up', 'username': 'username', 'password': 'pass'},
             'esxi': {
-                'type': 'esxi',
+                'type': 'up',
                 'username': 'username',
                 'password': 'pass',
             },
@@ -206,22 +220,27 @@ class PreferenceHandlerTestCase(TestCase):
                 'username': 'username',
                 'password': 'pass',
                 'community': 'some comunity',
-                'auth_algorithm': 'some auth algo',
+                'auth_algorithm': 'md5',
                 'privacy_password': 'privacy pass',
-                'privacy_algorithm': 'privacy algo',
+                'privacy_algorithm': 'aes',
             },
         }
 
         p_handler = PreferenceHandler(
-            '1234-1234', None, dummy.scan_collection, None
+            '1234-1234', None, dummy.scan_collection, None, None
         )
         ret = p_handler.build_credentials_as_prefs(cred_dict)
 
         self.assertEqual(len(ret), len(cred_out))
-        self.assertIn('auth_port_ssh|||22', cred_out)
+        self.assertIn('auth_port_ssh|||22', ret)
         self.assertIn(
             '1.3.6.1.4.1.25623.1.0.90023:1:entry:SMB login:|||username',
-            cred_out,
+            ret,
+        )
+        self.assertIn(
+            '1.3.6.1.4.1.25623.1.0.103591:8:'
+            'password:SSH privilege password:|||su_pass',
+            ret,
         )
 
     def test_build_alive_test_opt_empty(self):
@@ -230,7 +249,7 @@ class PreferenceHandlerTestCase(TestCase):
         target_options_dict = {'alive_test': '0'}
 
         p_handler = PreferenceHandler(
-            '1234-1234', None, dummy.scan_collection, None
+            '1234-1234', None, dummy.scan_collection, None, None
         )
         ret = p_handler.build_alive_test_opt_as_prefs(target_options_dict)
 
@@ -240,7 +259,7 @@ class PreferenceHandlerTestCase(TestCase):
         dummy = DummyDaemon()
         target_options_dict = {'alive_test_methods': '1', 'icmp': '0'}
         p_handler = PreferenceHandler(
-            '1234-1234', None, dummy.scan_collection, None
+            '1234-1234', None, dummy.scan_collection, None, None
         )
         ret = p_handler.build_alive_test_opt_as_prefs(target_options_dict)
         self.assertEqual(ret, {})
@@ -264,7 +283,7 @@ class PreferenceHandlerTestCase(TestCase):
 
         target_options_dict = {'alive_test': '2'}
         p_handler = PreferenceHandler(
-            '1234-1234', None, dummy.scan_collection, None
+            '1234-1234', None, dummy.scan_collection, None, None
         )
         ret = p_handler.build_alive_test_opt_as_prefs(target_options_dict)
 
@@ -274,7 +293,7 @@ class PreferenceHandlerTestCase(TestCase):
         dummy = DummyDaemon()
         target_options_dict = {'alive_test_methods': '1', 'icmp': '1'}
         p_handler = PreferenceHandler(
-            '1234-1234', None, dummy.scan_collection, None
+            '1234-1234', None, dummy.scan_collection, None, None
         )
         ret = p_handler.build_alive_test_opt_as_prefs(target_options_dict)
         self.assertEqual(ret, alive_test_out)
@@ -285,7 +304,7 @@ class PreferenceHandlerTestCase(TestCase):
 
         target_options_dict = {'alive_test': 'a'}
         p_handler = PreferenceHandler(
-            '1234-1234', None, dummy.scan_collection, None
+            '1234-1234', None, dummy.scan_collection, None, None
         )
         target_options = p_handler.build_alive_test_opt_as_prefs(
             target_options_dict
@@ -303,7 +322,7 @@ class PreferenceHandlerTestCase(TestCase):
         )
 
         p_handler = PreferenceHandler(
-            '1234-1234', mock_kb, dummy.scan_collection, None
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
         )
         p_handler.scan_id = '456-789'
         p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -321,7 +340,7 @@ class PreferenceHandlerTestCase(TestCase):
         dummy.scan_collection.get_ports = MagicMock(return_value='80,443')
 
         p_handler = PreferenceHandler(
-            '1234-1234', mock_kb, dummy.scan_collection, None
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
         )
         p_handler.scan_id = '456-789'
         p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -332,12 +351,25 @@ class PreferenceHandlerTestCase(TestCase):
             ['port_range|||80,443'],
         )
 
+    @patch('ospd_openvas.db.KbDB')
+    def test_set_ports_invalid(self, mock_kb):
+        dummy = DummyDaemon()
+
+        dummy.scan_collection.get_ports = MagicMock(return_value='2,-9,4')
+
+        p_handler = PreferenceHandler(
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
+        )
+        p_handler.scan_id = '456-789'
+        p_handler.kbdb.add_scan_preferences = MagicMock()
+        self.assertFalse(p_handler.prepare_ports_for_openvas())
+
     @patch('ospd_openvas.db.KbDB')
     def test_set_main_kbindex(self, mock_kb):
         dummy = DummyDaemon()
 
         p_handler = PreferenceHandler(
-            '1234-1234', mock_kb, dummy.scan_collection, None
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
         )
         p_handler.kbdb.add_scan_preferences = Mock()
         p_handler.kbdb.index = 2
@@ -354,14 +386,16 @@ class PreferenceHandlerTestCase(TestCase):
 
         creds = {
             'ssh': {
-                'type': 'ssh',
+                'type': 'up',
                 'port': '22',
                 'username': 'username',
                 'password': 'pass',
+                'priv_username': "privuser",
+                'priv_password': "privpass",
             },
-            'smb': {'type': 'smb', 'username': 'username', 'password': 'pass'},
+            'smb': {'type': 'up', 'username': 'username', 'password': 'pass'},
             'esxi': {
-                'type': 'esxi',
+                'type': 'up',
                 'username': 'username',
                 'password': 'pass',
             },
@@ -370,31 +404,32 @@ class PreferenceHandlerTestCase(TestCase):
                 'username': 'username',
                 'password': 'pass',
                 'community': 'some comunity',
-                'auth_algorithm': 'some auth algo',
+                'auth_algorithm': 'md5',
                 'privacy_password': 'privacy pass',
-                'privacy_algorithm': 'privacy algo',
+                'privacy_algorithm': 'aes',
             },
         }
 
         dummy.scan_collection.get_credentials = MagicMock(return_value=creds)
 
         p_handler = PreferenceHandler(
-            '1234-1234', mock_kb, dummy.scan_collection, None
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
         )
         p_handler.scan_id = '456-789'
         p_handler.kbdb.add_credentials_to_scan_preferences = MagicMock()
         ret = p_handler.prepare_credentials_for_openvas()
 
         self.assertTrue(ret)
+        assert_called_once(p_handler.kbdb.add_credentials_to_scan_preferences)
 
     @patch('ospd_openvas.db.KbDB')
-    def test_set_bad_credentials(self, mock_kb):
+    def test_set_bad_service_credentials(self, mock_kb):
         dummy = DummyDaemon()
 
         # bad cred type shh instead of ssh
         creds = {
             'shh': {
-                'type': 'ssh',
+                'type': 'up',
                 'port': '22',
                 'username': 'username',
                 'password': 'pass',
@@ -404,13 +439,280 @@ class PreferenceHandlerTestCase(TestCase):
         dummy.scan_collection.get_credentials = MagicMock(return_value=creds)
 
         p_handler = PreferenceHandler(
-            '1234-1234', mock_kb, dummy.scan_collection, None
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
+        )
+        p_handler.scan_id = '456-789'
+        p_handler.kbdb.add_scan_preferences = MagicMock()
+        ret = p_handler.prepare_credentials_for_openvas()
+        errors = p_handler.get_error_messages()
+
+        self.assertFalse(ret)
+        self.assertIn("Unknown service type for credential: shh", errors)
+
+    @patch('ospd_openvas.db.KbDB')
+    def test_set_bad_ssh_port_credentials(self, mock_kb):
+        dummy = DummyDaemon()
+
+        creds = {
+            'ssh': {
+                'type': 'up',
+                'port': 'ab',
+                'username': 'username',
+                'password': 'pass',
+            },
+        }
+
+        dummy.scan_collection.get_credentials = MagicMock(return_value=creds)
+
+        p_handler = PreferenceHandler(
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
+        )
+        p_handler.scan_id = '456-789'
+        p_handler.kbdb.add_scan_preferences = MagicMock()
+        ret = p_handler.prepare_credentials_for_openvas()
+        errors = p_handler.get_error_messages()
+
+        self.assertFalse(ret)
+        self.assertIn("Port for SSH 'ab' is not a valid number.", errors)
+
+    @patch('ospd_openvas.db.KbDB')
+    def test_missing_ssh_port_credentials(self, mock_kb):
+        dummy = DummyDaemon()
+
+        creds = {
+            'ssh': {
+                'type': 'up',
+                'username': 'username',
+                'password': 'pass',
+            },
+        }
+
+        dummy.scan_collection.get_credentials = MagicMock(return_value=creds)
+
+        p_handler = PreferenceHandler(
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
         )
         p_handler.scan_id = '456-789'
         p_handler.kbdb.add_scan_preferences = MagicMock()
         ret = p_handler.prepare_credentials_for_openvas()
 
+        self.assertTrue(ret)
+
+    @patch('ospd_openvas.db.KbDB')
+    def test_ssh_port_out_of_range_credentials(self, mock_kb):
+        dummy = DummyDaemon()
+
+        creds = {
+            'ssh': {
+                'type': 'up',
+                'port': '65536',
+                'username': 'username',
+                'password': 'pass',
+            },
+        }
+
+        dummy.scan_collection.get_credentials = MagicMock(return_value=creds)
+
+        p_handler = PreferenceHandler(
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
+        )
+        p_handler.scan_id = '456-789'
+        p_handler.kbdb.add_scan_preferences = MagicMock()
+        ret = p_handler.prepare_credentials_for_openvas()
+        errors = p_handler.get_error_messages()
+
         self.assertFalse(ret)
+        self.assertIn("Port for SSH is out of range (1-65535): 65536", errors)
+
+    @patch('ospd_openvas.db.KbDB')
+    def test_bad_type_for_ssh_credentials(self, mock_kb):
+        dummy = DummyDaemon()
+
+        creds = {
+            'ssh': {
+                'type': 'ups',
+                'port': '22',
+                'username': 'username',
+                'password': 'pass',
+            },
+        }
+
+        dummy.scan_collection.get_credentials = MagicMock(return_value=creds)
+
+        p_handler = PreferenceHandler(
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
+        )
+        p_handler.scan_id = '456-789'
+        p_handler.kbdb.add_scan_preferences = MagicMock()
+        ret = p_handler.prepare_credentials_for_openvas()
+        errors = p_handler.get_error_messages()
+
+        self.assertFalse(ret)
+        self.assertIn(
+            "Unknown Credential Type for SSH: "
+            + "ups"
+            + ". Use 'up' for Username + Password"
+            + " or 'usk' for Username + SSH Key.",
+            errors,
+        )
+
+    @patch('ospd_openvas.db.KbDB')
+    def test_missing_type_for_ssh_credentials(self, mock_kb):
+        dummy = DummyDaemon()
+
+        creds = {
+            'ssh': {
+                'port': '22',
+                'username': 'username',
+                'password': 'pass',
+            },
+        }
+
+        dummy.scan_collection.get_credentials = MagicMock(return_value=creds)
+
+        p_handler = PreferenceHandler(
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
+        )
+        p_handler.scan_id = '456-789'
+        p_handler.kbdb.add_scan_preferences = MagicMock()
+        ret = p_handler.prepare_credentials_for_openvas()
+        errors = p_handler.get_error_messages()
+
+        self.assertFalse(ret)
+        self.assertIn(
+            "Missing Credential Type for SSH."
+            + " Use 'up' for Username + Password"
+            + " or 'usk' for Username + SSH Key.",
+            errors,
+        )
+
+    @patch('ospd_openvas.db.KbDB')
+    def test_snmp_no_priv_alg_but_pw_credentials(self, mock_kb):
+        dummy = DummyDaemon()
+
+        creds = {
+            'snmp': {
+                'type': 'snmp',
+                'username': 'username',
+                'password': 'pass',
+                'community': 'some comunity',
+                'auth_algorithm': 'sha1',
+                'privacy_password': 'privacy pass',
+            },
+        }
+
+        dummy.scan_collection.get_credentials = MagicMock(return_value=creds)
+
+        p_handler = PreferenceHandler(
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
+        )
+        p_handler.scan_id = '456-789'
+        p_handler.kbdb.add_scan_preferences = MagicMock()
+        ret = p_handler.prepare_credentials_for_openvas()
+        errors = p_handler.get_error_messages()
+
+        self.assertFalse(ret)
+        self.assertIn(
+            "When no privacy algorithm is used, the privacy"
+            + " password also has to be empty.",
+            errors,
+        )
+
+    @patch('ospd_openvas.db.KbDB')
+    def test_snmp_unknown_priv_alg_credentials(self, mock_kb):
+        dummy = DummyDaemon()
+
+        creds = {
+            'snmp': {
+                'type': 'snmp',
+                'username': 'username',
+                'password': 'pass',
+                'community': 'some comunity',
+                'auth_algorithm': 'sha1',
+                'privacy_password': 'privacy pass',
+                'privacy_algorithm': 'das',
+            },
+        }
+
+        dummy.scan_collection.get_credentials = MagicMock(return_value=creds)
+
+        p_handler = PreferenceHandler(
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
+        )
+        p_handler.scan_id = '456-789'
+        p_handler.kbdb.add_scan_preferences = MagicMock()
+        ret = p_handler.prepare_credentials_for_openvas()
+        errors = p_handler.get_error_messages()
+
+        self.assertFalse(ret)
+        self.assertIn(
+            "Unknown privacy algorithm used: "
+            + "das"
+            + ". Use 'aes', 'des' or '' (none).",
+            errors,
+        )
+
+    @patch('ospd_openvas.db.KbDB')
+    def test_snmp_missing_auth_alg_credentials(self, mock_kb):
+        dummy = DummyDaemon()
+
+        creds = {
+            'snmp': {
+                'type': 'snmp',
+                'username': 'username',
+                'password': 'pass',
+                'community': 'some comunity',
+            },
+        }
+
+        dummy.scan_collection.get_credentials = MagicMock(return_value=creds)
+
+        p_handler = PreferenceHandler(
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
+        )
+        p_handler.scan_id = '456-789'
+        p_handler.kbdb.add_scan_preferences = MagicMock()
+        ret = p_handler.prepare_credentials_for_openvas()
+        errors = p_handler.get_error_messages()
+
+        self.assertFalse(ret)
+        self.assertIn(
+            "Missing authentication algorithm for SNMP."
+            + " Use 'md5' or 'sha1'.",
+            errors,
+        )
+
+    @patch('ospd_openvas.db.KbDB')
+    def test_snmp_unknown_auth_alg_credentials(self, mock_kb):
+        dummy = DummyDaemon()
+
+        creds = {
+            'snmp': {
+                'type': 'snmp',
+                'username': 'username',
+                'password': 'pass',
+                'community': 'some comunity',
+                'auth_algorithm': 'sha2',
+            },
+        }
+
+        dummy.scan_collection.get_credentials = MagicMock(return_value=creds)
+
+        p_handler = PreferenceHandler(
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
+        )
+        p_handler.scan_id = '456-789'
+        p_handler.kbdb.add_scan_preferences = MagicMock()
+        ret = p_handler.prepare_credentials_for_openvas()
+        errors = p_handler.get_error_messages()
+
+        self.assertFalse(ret)
+        self.assertIn(
+            "Unknown authentication algorithm: "
+            + "sha2"
+            + ". Use 'md5' or 'sha1'.",
+            errors,
+        )
 
     @patch('ospd_openvas.db.KbDB')
     def test_set_credentials_empty(self, mock_kb):
@@ -421,7 +723,7 @@ class PreferenceHandlerTestCase(TestCase):
         dummy.scan_collection.get_credentials = MagicMock(return_value=creds)
 
         p_handler = PreferenceHandler(
-            '1234-1234', mock_kb, dummy.scan_collection, None
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
         )
         p_handler.scan_id = '456-789'
         p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -438,7 +740,7 @@ class PreferenceHandlerTestCase(TestCase):
         dummy.scan_collection.get_exclude_hosts = MagicMock(return_value=exc)
 
         p_handler = PreferenceHandler(
-            '1234-1234', mock_kb, dummy.scan_collection, None
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
         )
         p_handler.scan_id = '456-789'
         p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -458,7 +760,7 @@ class PreferenceHandlerTestCase(TestCase):
         dummy.scan_collection.get_exclude_hosts = MagicMock(return_value=exc)
 
         p_handler = PreferenceHandler(
-            '1234-1234', mock_kb, dummy.scan_collection, None
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
         )
         p_handler.scan_id = '456-789'
         p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -485,7 +787,7 @@ class PreferenceHandlerTestCase(TestCase):
         dummy.scan_collection.get_options = MagicMock(return_value=opt)
 
         p_handler = PreferenceHandler(
-            '1234-1234', mock_kb, dummy.scan_collection, None
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
         )
         p_handler.scan_id = '456-789'
         p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -503,7 +805,7 @@ class PreferenceHandlerTestCase(TestCase):
         dummy.scan_collection.get_target_options = MagicMock(return_value=t_opt)
 
         p_handler = PreferenceHandler(
-            '1234-1234', mock_kb, dummy.scan_collection, None
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
         )
         p_handler.scan_id = '456-789'
         p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -526,7 +828,7 @@ class PreferenceHandlerTestCase(TestCase):
         dummy.scan_collection.get_target_options = MagicMock(return_value=t_opt)
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -541,7 +843,7 @@ class PreferenceHandlerTestCase(TestCase):
         ov_setting = {BOREAS_SETTING_NAME: 1}
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -557,7 +859,7 @@ class PreferenceHandlerTestCase(TestCase):
         ov_setting = {BOREAS_SETTING_NAME: 1}
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -573,7 +875,7 @@ class PreferenceHandlerTestCase(TestCase):
         ov_setting = {BOREAS_SETTING_NAME: 1}
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -589,7 +891,7 @@ class PreferenceHandlerTestCase(TestCase):
         ov_setting = {BOREAS_SETTING_NAME: 1}
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -608,7 +910,7 @@ class PreferenceHandlerTestCase(TestCase):
         ov_setting = {BOREAS_SETTING_NAME: 1}
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -631,7 +933,7 @@ class PreferenceHandlerTestCase(TestCase):
         dummy.scan_collection.get_target_options = MagicMock(return_value=t_opt)
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -646,7 +948,7 @@ class PreferenceHandlerTestCase(TestCase):
         ov_setting = {BOREAS_SETTING_NAME: 1}
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -662,7 +964,7 @@ class PreferenceHandlerTestCase(TestCase):
         ov_setting = {BOREAS_SETTING_NAME: 1}
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -678,7 +980,7 @@ class PreferenceHandlerTestCase(TestCase):
         ov_setting = {BOREAS_SETTING_NAME: 1}
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -694,7 +996,7 @@ class PreferenceHandlerTestCase(TestCase):
         ov_setting = {BOREAS_SETTING_NAME: 1}
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -710,7 +1012,7 @@ class PreferenceHandlerTestCase(TestCase):
         ov_setting = {BOREAS_SETTING_NAME: 1}
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -726,7 +1028,7 @@ class PreferenceHandlerTestCase(TestCase):
         ov_setting = {BOREAS_SETTING_NAME: 1}
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -749,7 +1051,7 @@ class PreferenceHandlerTestCase(TestCase):
         ov_setting = {BOREAS_SETTING_NAME: 1}
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -769,7 +1071,7 @@ class PreferenceHandlerTestCase(TestCase):
         ov_setting = {BOREAS_SETTING_NAME: 1}
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -795,7 +1097,7 @@ class PreferenceHandlerTestCase(TestCase):
         ov_setting = {BOREAS_SETTING_NAME: 1}
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -813,7 +1115,7 @@ class PreferenceHandlerTestCase(TestCase):
         ov_setting = {}
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -832,7 +1134,7 @@ class PreferenceHandlerTestCase(TestCase):
 
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler.scan_id = '456-789'
             p_handler.kbdb.add_scan_preferences = MagicMock()
@@ -851,7 +1153,7 @@ class PreferenceHandlerTestCase(TestCase):
 
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler._nvts_params = {}  # pylint: disable = protected-access
             p_handler.scan_id = '456-789'
@@ -871,7 +1173,7 @@ class PreferenceHandlerTestCase(TestCase):
 
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler._nvts_params = {}  # pylint: disable = protected-access
             p_handler.scan_id = '456-789'
@@ -903,7 +1205,7 @@ class PreferenceHandlerTestCase(TestCase):
 
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler._nvts_params = {}  # pylint: disable = protected-access
             p_handler.scan_id = '456-789'
@@ -941,7 +1243,7 @@ class PreferenceHandlerTestCase(TestCase):
 
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler._nvts_params = {}  # pylint: disable = protected-access
             p_handler.scan_id = '456-789'
@@ -964,7 +1266,7 @@ class PreferenceHandlerTestCase(TestCase):
 
         with patch.object(Openvas, 'get_settings', return_value=ov_setting):
             p_handler = PreferenceHandler(
-                '1234-1234', mock_kb, dummy.scan_collection, None
+                '1234-1234', mock_kb, dummy.scan_collection, None, None
             )
             p_handler._nvts_params = {}  # pylint: disable = protected-access
             p_handler.scan_id = '456-789'
@@ -1058,7 +1360,7 @@ class PreferenceHandlerTestCase(TestCase):
         ]
 
         p_handler = PreferenceHandler(
-            '1234-1234', mock_kb, dummy.scan_collection, None
+            '1234-1234', mock_kb, dummy.scan_collection, None, None
         )
         p_handler._nvts_params = {  # pylint: disable = protected-access
             "1.3.6.1.4.1.25623.1.0.100315:1:checkbox:Do a TCP ping": "no"
@@ -1076,7 +1378,7 @@ class PreferenceHandlerTestCase(TestCase):
         dummy = DummyDaemon()
 
         p_handler = PreferenceHandler(
-            '456-789', mock_kb, dummy.scan_collection, None
+            '456-789', mock_kb, dummy.scan_collection, None, None
         )
         p_handler._nvts_params = {}  # pylint: disable = protected-access
         p_handler.kbdb.add_scan_preferences = MagicMock()
