@@ -40,6 +40,7 @@ from .helper import (
     FakeStream,
     FakeDataManager,
     FakePsutil,
+    DummyXML,
 )
 
 
@@ -63,8 +64,9 @@ class FakeStartProcess:
         return self.run_mock
 
     def __repr__(self):
-        return "<FakeProcess func={} args={} kwargs={}>".format(
-            self.func, self.args, self.kwargs
+        return (
+            f"<FakeProcess func={self.func} "
+            f"args={self.args} kwargs={self.kwargs}>"
         )
 
 
@@ -175,6 +177,9 @@ class ScanTestCase(unittest.TestCase):
         fs = FakeStream()
         self.daemon.add_vt('1.2.3.4', 'A vulnerability test')
         self.daemon.set_vts_version('today')
+        self.daemon.set_feed_vendor('Greenbone')
+        self.daemon.set_feed_name('GCF')
+        self.daemon.set_feed_home('www.greenbone.net')
         self.daemon.handle_command('<get_vts version_only="1"/>', fs)
         response = fs.get_response()
 
@@ -182,6 +187,12 @@ class ScanTestCase(unittest.TestCase):
 
         vts_version = response.find('vts').attrib['vts_version']
         self.assertEqual(vts_version, self.daemon.get_vts_version())
+        feed_vendor = response.find('vts').attrib['feed_vendor']
+        self.assertEqual(feed_vendor, self.daemon.get_feed_vendor())
+        feed_home = response.find('vts').attrib['feed_home']
+        self.assertEqual(feed_home, self.daemon.get_feed_home())
+        feed_name = response.find('vts').attrib['feed_name']
+        self.assertEqual(feed_name, self.daemon.get_feed_name())
 
         vts = response.find('vts')
         self.assertIsNone(vts.find('vt'))
@@ -206,7 +217,6 @@ class ScanTestCase(unittest.TestCase):
         self.daemon.add_vt(
             '1.2.3.4',
             'A vulnerability test',
-            vt_params="a",
             vt_modification_time='19000202',
         )
         fs = FakeStream()
@@ -233,12 +243,12 @@ class ScanTestCase(unittest.TestCase):
         self.daemon.add_vt(
             '1.2.3.4',
             'A vulnerability test',
-            vt_params="a",
             vt_modification_time='19000202',
         )
         fs = FakeStream()
         self.daemon.handle_command(
-            '<get_vts filter="modification_time&lt;19000203"></get_vts>', fs
+            '<get_vts filter="modification_time&lt;19000203"></get_vts>',
+            fs,
         )
         response = fs.get_response()
 
@@ -277,7 +287,10 @@ class ScanTestCase(unittest.TestCase):
         vts = response.find('vts')
         self.assertIsNotNone(vts.find('vt'))
 
-    def test_get_vts_multiple_vts_with_custom(self):
+    @patch('ospd.ospd.XmlStringVTHelper')
+    def test_get_vts_multiple_vts_with_custom(self, mxml):
+        mxml.side_effect = DummyXML
+
         self.daemon.add_vt('1.2.3.4', 'A vulnerability test', custom='b')
         self.daemon.add_vt(
             '4.3.2.1', 'Another vulnerability test with custom info', custom='b'
@@ -294,9 +307,11 @@ class ScanTestCase(unittest.TestCase):
 
         self.assertEqual(3, len(custom))
 
-    def test_get_vts_vts_with_params(self):
+    @patch('ospd.ospd.XmlStringVTHelper')
+    def test_get_vts_vts_with_params(self, mxml):
+        mxml.side_effect = DummyXML
         self.daemon.add_vt(
-            '1.2.3.4', 'A vulnerability test', vt_params="a", custom="b"
+            '1.2.3.4', 'A vulnerability test', vt_params='a', custom='b'
         )
         fs = FakeStream()
 
@@ -320,7 +335,9 @@ class ScanTestCase(unittest.TestCase):
         params = response.findall('vts/vt/params/param')
         self.assertEqual(2, len(params))
 
-    def test_get_vts_vts_with_refs(self):
+    @patch('ospd.ospd.XmlStringVTHelper')
+    def test_get_vts_vts_with_refs(self, mxml):
+        mxml.side_effect = DummyXML
         self.daemon.add_vt(
             '1.2.3.4',
             'A vulnerability test',
@@ -345,18 +362,15 @@ class ScanTestCase(unittest.TestCase):
         vt_params = response[0][0].findall('params')
         self.assertEqual(1, len(vt_params))
 
-        custom = response[0][0].findall('custom')
-        self.assertEqual(1, len(custom))
-
         refs = response.findall('vts/vt/refs/ref')
         self.assertEqual(2, len(refs))
 
-    def test_get_vts_vts_with_dependencies(self):
+    @patch('ospd.ospd.XmlStringVTHelper')
+    def test_get_vts_vts_with_dependencies(self, mxml):
+        mxml.side_effect = DummyXML
         self.daemon.add_vt(
             '1.2.3.4',
             'A vulnerability test',
-            vt_params="a",
-            custom="b",
             vt_dependencies="c",
         )
         fs = FakeStream()
@@ -372,8 +386,6 @@ class ScanTestCase(unittest.TestCase):
         self.daemon.add_vt(
             '1.2.3.4',
             'A vulnerability test',
-            vt_params="a",
-            custom="b",
             severities="c",
         )
         fs = FakeStream()
@@ -388,8 +400,6 @@ class ScanTestCase(unittest.TestCase):
         self.daemon.add_vt(
             '1.2.3.4',
             'A vulnerability test',
-            vt_params="a",
-            custom="b",
             detection="c",
             qod_t="d",
         )
@@ -405,8 +415,6 @@ class ScanTestCase(unittest.TestCase):
         self.daemon.add_vt(
             '1.2.3.4',
             'A vulnerability test',
-            vt_params="a",
-            custom="b",
             detection="c",
             qod_v="d",
         )
@@ -418,13 +426,13 @@ class ScanTestCase(unittest.TestCase):
         detection = response.findall('vts/vt/detection')
         self.assertEqual(1, len(detection))
 
-    def test_get_vts_vts_with_summary(self):
+    @patch('ospd.ospd.XmlStringVTHelper')
+    def test_get_vts_vts_with_summary(self, mxml):
+        mxml.side_effect = DummyXML
         self.daemon.add_vt(
             '1.2.3.4',
             'A vulnerability test',
-            vt_params="a",
-            custom="b",
-            summary="c",
+            summary="a",
         )
         fs = FakeStream()
 
@@ -438,8 +446,6 @@ class ScanTestCase(unittest.TestCase):
         self.daemon.add_vt(
             '1.2.3.4',
             'A vulnerability test',
-            vt_params="a",
-            custom="b",
             impact="c",
         )
         fs = FakeStream()
@@ -454,8 +460,6 @@ class ScanTestCase(unittest.TestCase):
         self.daemon.add_vt(
             '1.2.3.4',
             'A vulnerability test',
-            vt_params="a",
-            custom="b",
             affected="c",
         )
         fs = FakeStream()
@@ -470,8 +474,6 @@ class ScanTestCase(unittest.TestCase):
         self.daemon.add_vt(
             '1.2.3.4',
             'A vulnerability test',
-            vt_params="a",
-            custom="b",
             insight="c",
         )
         fs = FakeStream()
@@ -486,8 +488,6 @@ class ScanTestCase(unittest.TestCase):
         self.daemon.add_vt(
             '1.2.3.4',
             'A vulnerability test',
-            vt_params="a",
-            custom="b",
             solution="c",
             solution_t="d",
             solution_m="e",
@@ -504,7 +504,6 @@ class ScanTestCase(unittest.TestCase):
         self.daemon.add_vt(
             '1.2.3.4',
             'A vulnerability test',
-            vt_params="a",
             vt_creation_time='01-01-1900',
         )
         fs = FakeStream()
@@ -522,7 +521,6 @@ class ScanTestCase(unittest.TestCase):
         self.daemon.add_vt(
             '1.2.3.4',
             'A vulnerability test',
-            vt_params="a",
             vt_modification_time='02-01-1900',
         )
         fs = FakeStream()
@@ -554,7 +552,7 @@ class ScanTestCase(unittest.TestCase):
         while not finished:
             fs = FakeStream()
             self.daemon.handle_command(
-                '<get_scans scan_id="%s" details="1"/>' % scan_id, fs
+                f'<get_scans scan_id="{scan_id}" details="1"/>', fs
             )
             response = fs.get_response()
 
@@ -570,7 +568,7 @@ class ScanTestCase(unittest.TestCase):
 
             fs = FakeStream()
             self.daemon.handle_command(
-                '<get_scans scan_id="%s" details="1"/>' % scan_id, fs
+                f'<get_scans scan_id="{scan_id}" details="1"/>', fs
             )
             response = fs.get_response()
 
@@ -615,7 +613,7 @@ class ScanTestCase(unittest.TestCase):
         while not finished:
             fs = FakeStream()
             self.daemon.handle_command(
-                '<get_scans scan_id="%s" details="1"/>' % scan_id, fs
+                f'<get_scans scan_id="{scan_id}" details="1"/>', fs
             )
             response = fs.get_response()
 
@@ -634,7 +632,7 @@ class ScanTestCase(unittest.TestCase):
             fs = FakeStream()
 
             self.daemon.handle_command(
-                '<get_scans scan_id="%s" details="1"/>' % scan_id, fs
+                f'<get_scans scan_id="{scan_id}" details="1"/>', fs
             )
             response = fs.get_response()
 
@@ -642,7 +640,7 @@ class ScanTestCase(unittest.TestCase):
             response.findtext('scan/results/result'), 'something went wrong'
         )
         fs = FakeStream()
-        self.daemon.handle_command('<delete_scan scan_id="%s" />' % scan_id, fs)
+        self.daemon.handle_command(f'<delete_scan scan_id="{scan_id}" />', fs)
         response = fs.get_response()
 
         self.assertEqual(response.get('status'), '200')
@@ -666,7 +664,7 @@ class ScanTestCase(unittest.TestCase):
         time.sleep(1)
 
         fs = FakeStream()
-        self.daemon.handle_command('<get_scans scan_id="%s"/>' % scan_id, fs)
+        self.daemon.handle_command(f'<get_scans scan_id="{scan_id}"/>', fs)
         response = fs.get_response()
 
         self.assertEqual(
@@ -674,7 +672,7 @@ class ScanTestCase(unittest.TestCase):
         )
         fs = FakeStream()
         self.daemon.handle_command(
-            '<get_scans scan_id="%s" pop_results="1"/>' % scan_id, fs
+            f'<get_scans scan_id="{scan_id}" pop_results="1"/>', fs
         )
         response = fs.get_response()
 
@@ -684,7 +682,7 @@ class ScanTestCase(unittest.TestCase):
 
         fs = FakeStream()
         self.daemon.handle_command(
-            '<get_scans scan_id="%s" details="0" pop_results="1"/>' % scan_id,
+            f'<get_scans scan_id="{scan_id}" details="0" pop_results="1"/>',
             fs,
         )
         response = fs.get_response()
@@ -708,8 +706,7 @@ class ScanTestCase(unittest.TestCase):
 
         fs = FakeStream()
         self.daemon.handle_command(
-            '<get_scans scan_id="%s" pop_results="1" max_results="1"/>'
-            % scan_id,
+            f'<get_scans scan_id="{scan_id}" pop_results="1" max_results="1"/>',
             fs,
         )
 
@@ -719,7 +716,7 @@ class ScanTestCase(unittest.TestCase):
 
         fs = FakeStream()
         self.daemon.handle_command(
-            '<get_scans scan_id="%s" pop_results="1"/>' % scan_id, fs
+            f'<get_scans scan_id="{scan_id}" pop_results="1"/>', fs
         )
         response = fs.get_response()
         self.assertEqual(len(response.findall('scan/results/result')), 2)
@@ -741,7 +738,8 @@ class ScanTestCase(unittest.TestCase):
 
         fs = FakeStream()
         self.daemon.handle_command(
-            '<get_scans scan_id="%s" pop_results="1"/>' % scan_id, fs
+            f'<get_scans scan_id="{scan_id}" pop_results="1"/>',
+            fs,
         )
 
         res_len = len(
@@ -771,7 +769,8 @@ class ScanTestCase(unittest.TestCase):
 
         fs = FakeStream(return_value=False)
         self.daemon.handle_command(
-            '<get_scans scan_id="%s" pop_results="1"/>' % scan_id, fs
+            f'<get_scans scan_id="{scan_id}" pop_results="1"/>',
+            fs,
         )
 
         res_len = len(
@@ -785,23 +784,27 @@ class ScanTestCase(unittest.TestCase):
         self.assertEqual(res_len, 0)
 
     def test_billon_laughs(self):
-        # pylint: disable=line-too-long
 
         lol = (
-            '<?xml version="1.0"?>'
-            '<!DOCTYPE lolz ['
-            ' <!ENTITY lol "lol">'
-            ' <!ELEMENT lolz (#PCDATA)>'
-            ' <!ENTITY lol1 "&lol;&lol;&lol;&lol;&lol;&lol;&lol;&lol;&lol;&lol;">'
-            ' <!ENTITY lol2 "&lol1;&lol1;&lol1;&lol1;&lol1;&lol1;&lol1;&lol1;&lol1;&lol1;">'
-            ' <!ENTITY lol3 "&lol2;&lol2;&lol2;&lol2;&lol2;&lol2;&lol2;&lol2;&lol2;&lol2;">'
-            ' <!ENTITY lol4 "&lol3;&lol3;&lol3;&lol3;&lol3;&lol3;&lol3;&lol3;&lol3;&lol3;">'
-            ' <!ENTITY lol5 "&lol4;&lol4;&lol4;&lol4;&lol4;&lol4;&lol4;&lol4;&lol4;&lol4;">'
-            ' <!ENTITY lol6 "&lol5;&lol5;&lol5;&lol5;&lol5;&lol5;&lol5;&lol5;&lol5;&lol5;">'
-            ' <!ENTITY lol7 "&lol6;&lol6;&lol6;&lol6;&lol6;&lol6;&lol6;&lol6;&lol6;&lol6;">'
-            ' <!ENTITY lol8 "&lol7;&lol7;&lol7;&lol7;&lol7;&lol7;&lol7;&lol7;&lol7;&lol7;">'
-            ' <!ENTITY lol9 "&lol8;&lol8;&lol8;&lol8;&lol8;&lol8;&lol8;&lol8;&lol8;&lol8;">'
-            ']>'
+            '<?xml version="1.0"?><!DOCTYPE lolz [ <!ENTITY lol "lol">'
+            ' <!ELEMENT lolz (#PCDATA)> <!ENTITY lol1'
+            ' "&lol;&lol;&lol;&lol;&lol;&lol;&lol;&lol;&lol;&lol;"> <!ENTITY'
+            ' lol2'
+            ' "&lol1;&lol1;&lol1;&lol1;&lol1;&lol1;&lol1;&lol1;&lol1;&lol1;">'
+            ' <!ENTITY lol3'
+            ' "&lol2;&lol2;&lol2;&lol2;&lol2;&lol2;&lol2;&lol2;&lol2;&lol2;">'
+            ' <!ENTITY lol4'
+            ' "&lol3;&lol3;&lol3;&lol3;&lol3;&lol3;&lol3;&lol3;&lol3;&lol3;">'
+            ' <!ENTITY lol5'
+            ' "&lol4;&lol4;&lol4;&lol4;&lol4;&lol4;&lol4;&lol4;&lol4;&lol4;">'
+            ' <!ENTITY lol6'
+            ' "&lol5;&lol5;&lol5;&lol5;&lol5;&lol5;&lol5;&lol5;&lol5;&lol5;">'
+            ' <!ENTITY lol7'
+            ' "&lol6;&lol6;&lol6;&lol6;&lol6;&lol6;&lol6;&lol6;&lol6;&lol6;">'
+            ' <!ENTITY lol8'
+            ' "&lol7;&lol7;&lol7;&lol7;&lol7;&lol7;&lol7;&lol7;&lol7;&lol7;">'
+            ' <!ENTITY lol9'
+            ' "&lol8;&lol8;&lol8;&lol8;&lol8;&lol8;&lol8;&lol8;&lol8;&lol8;">]>'
         )
         fs = FakeStream()
         self.assertRaises(
@@ -867,7 +870,9 @@ class ScanTestCase(unittest.TestCase):
 
         self.assertEqual(response.get('status'), '200')
 
-        cred_dict = {'snmp': {'type': 'up', 'community': ''}}
+        cred_dict = {
+            'snmp': {'type': 'up', 'community': ''},
+        }
         scan_id = response.findtext('id')
         response = self.daemon.get_scan_credentials(scan_id)
         self.assertEqual(response, cred_dict)
@@ -891,7 +896,7 @@ class ScanTestCase(unittest.TestCase):
         scan_id = response.findtext('id')
 
         fs = FakeStream()
-        self.daemon.handle_command('<get_scans scan_id="%s"/>' % scan_id, fs)
+        self.daemon.handle_command(f'<get_scans scan_id="{scan_id}"/>', fs)
         response = fs.get_response()
 
         scan_res = response.find('scan')
@@ -988,7 +993,11 @@ class ScanTestCase(unittest.TestCase):
         time.sleep(1)
         target_options = self.daemon.get_scan_target_options(scan_id)
         self.assertEqual(
-            target_options, {'alive_test_methods': '1', 'icmp': '1'}
+            target_options,
+            {
+                'alive_test_methods': '1',
+                'icmp': '1',
+            },
         )
 
     def test_progress(self):
@@ -1065,7 +1074,7 @@ class ScanTestCase(unittest.TestCase):
         while self.daemon.get_scan_status(scan_id) == ScanStatus.INIT:
             fs = FakeStream()
             self.daemon.handle_command(
-                '<get_scans scan_id="%s" details="0" progress="0"/>' % scan_id,
+                f'<get_scans scan_id="{scan_id}" details="0" progress="0"/>',
                 fs,
             )
         response = fs.get_response()
@@ -1365,7 +1374,8 @@ class ScanTestCase(unittest.TestCase):
 
         fs = FakeStream()
         self.daemon.handle_command(
-            '<get_scans scan_id="%s" details="0" progress="1"/>' % scan_id, fs
+            f'<get_scans scan_id="{scan_id}" details="0" progress="1"/>',
+            fs,
         )
         response = fs.get_response()
 
@@ -1428,7 +1438,7 @@ class ScanTestCase(unittest.TestCase):
         assert_called_once(mock_create_process)
         assert_called_once(mock_process.start)
 
-        self.daemon.handle_command('<stop_scan scan_id="%s" />' % scan_id, fs)
+        self.daemon.handle_command(f'<stop_scan scan_id="{scan_id}" />', fs)
 
         fs = FakeStream()
         cmd = (
@@ -1441,7 +1451,10 @@ class ScanTestCase(unittest.TestCase):
             '</start_scan>'
         )
 
-        self.daemon.handle_command(cmd, fs)
+        self.daemon.handle_command(
+            cmd,
+            fs,
+        )
         self.daemon.start_queued_scans()
 
         response = fs.get_response()
@@ -1473,7 +1486,7 @@ class ScanTestCase(unittest.TestCase):
 
         fs = FakeStream()
         self.daemon.handle_command(
-            '<get_scans scan_id="%s" details="1"/>' % scan_id, fs
+            f'<get_scans scan_id="{scan_id}" details="1"/>', fs
         )
         response = fs.get_response()
 
@@ -1509,7 +1522,7 @@ class ScanTestCase(unittest.TestCase):
 
         fs = FakeStream()
         self.daemon.handle_command(
-            '<get_scans scan_id="%s" details="1"/>' % scan_id, fs
+            f'<get_scans scan_id="{scan_id}" details="1"/>', fs
         )
         response = fs.get_response()
 
